# coding: utf-8

"""
    Yahoo!広告 ディスプレイ広告 API リファレンス / Yahoo! Ads Display Ads API Reference

    <div lang=\"ja\">Yahoo!広告 ディスプレイ広告 APIのWebサービスについて説明します。<br> 「Try it out」のご利用には、事前にアプリケーションの登録が必要です。また、アプリケーションのリダイレクトURIの1つに<br> https://yahoojp-marketing.github.io/ads-display-api-documents/oauth2-redirect.htmlを登録してください。 </div> <div lang=\"en\">Display Ads API Web Services supported in Yahoo! Ads API.<br> When you use \"Try it out\", you need to register your application in advance.<br> As one of redirect URI for application, you need to set \"https://yahoojp-marketing.github.io/ads-display-api-documents/oauth2-redirect.html\". </div>   # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from yahoo_ads_display.configuration import Configuration


class Stats(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'imps': 'int',
        'imps_prev': 'float',
        'click_cnt': 'int',
        'click_rate': 'float',
        'click_rate_prev': 'float',
        'cost': 'float',
        'avg_cpc': 'float',
        'conversions': 'int',
        'conversion_rate': 'float',
        'conversions_via_ad_click': 'int',
        'conversion_rate_via_ad_click': 'float',
        'all_conversions': 'int',
        'all_conversion_rate': 'float',
        'cpa': 'str',
        'conversion_value': 'str',
        'value_per_conversions': 'str',
        'conv_value_per_cost': 'float',
        'all_conv_value_per_cost': 'float',
        'conv_value_via_ad_click_per_cost': 'float',
        'all_conversion_value': 'str',
        'value_per_all_conversions': 'str',
        'conversion_value_via_ad_click': 'str',
        'value_per_conversions_via_ad_click': 'str',
        'cpa_via_ad_click': 'str',
        'all_cpa': 'str',
        'cross_device_conversions': 'int',
        'avg_deliver_rank': 'float',
        'measured_imps': 'float',
        'total_vimps': 'int',
        'measured_imps_rate': 'float',
        'vimps': 'int',
        'viewable_imps_rate': 'float',
        'in_view_rate': 'float',
        'viewable_clicks': 'float',
        'in_view_click_cnt': 'int',
        'viewable_click_rate': 'float',
        'in_view_click_rate': 'float',
        'paid_video_views': 'int',
        'paid_video_view_rate': 'float',
        'average_cpv': 'float',
        'video_views': 'int',
        'video_views_to25': 'int',
        'video_views_to50': 'int',
        'video_views_to75': 'int',
        'video_views_to95': 'int',
        'video_views_to100': 'int',
        'video_views_to3_sec': 'int',
        'video_views_to10_sec': 'int',
        'average_rate_video_viewed': 'float',
        'average_duration_video_viewed': 'float',
        'impression_share': 'float',
        'budget_impression_share_lost_rate': 'float',
        'rank_impression_share_lost_rate': 'float'
    }

    attribute_map = {
        'imps': 'imps',
        'imps_prev': 'impsPrev',
        'click_cnt': 'clickCnt',
        'click_rate': 'clickRate',
        'click_rate_prev': 'clickRatePrev',
        'cost': 'cost',
        'avg_cpc': 'avgCpc',
        'conversions': 'conversions',
        'conversion_rate': 'conversionRate',
        'conversions_via_ad_click': 'conversionsViaAdClick',
        'conversion_rate_via_ad_click': 'conversionRateViaAdClick',
        'all_conversions': 'allConversions',
        'all_conversion_rate': 'allConversionRate',
        'cpa': 'cpa',
        'conversion_value': 'conversionValue',
        'value_per_conversions': 'valuePerConversions',
        'conv_value_per_cost': 'convValuePerCost',
        'all_conv_value_per_cost': 'allConvValuePerCost',
        'conv_value_via_ad_click_per_cost': 'convValueViaAdClickPerCost',
        'all_conversion_value': 'allConversionValue',
        'value_per_all_conversions': 'valuePerAllConversions',
        'conversion_value_via_ad_click': 'conversionValueViaAdClick',
        'value_per_conversions_via_ad_click': 'valuePerConversionsViaAdClick',
        'cpa_via_ad_click': 'cpaViaAdClick',
        'all_cpa': 'allCpa',
        'cross_device_conversions': 'crossDeviceConversions',
        'avg_deliver_rank': 'avgDeliverRank',
        'measured_imps': 'measuredImps',
        'total_vimps': 'totalVimps',
        'measured_imps_rate': 'measuredImpsRate',
        'vimps': 'vimps',
        'viewable_imps_rate': 'viewableImpsRate',
        'in_view_rate': 'inViewRate',
        'viewable_clicks': 'viewableClicks',
        'in_view_click_cnt': 'inViewClickCnt',
        'viewable_click_rate': 'viewableClickRate',
        'in_view_click_rate': 'inViewClickRate',
        'paid_video_views': 'paidVideoViews',
        'paid_video_view_rate': 'paidVideoViewRate',
        'average_cpv': 'averageCpv',
        'video_views': 'videoViews',
        'video_views_to25': 'videoViewsTo25',
        'video_views_to50': 'videoViewsTo50',
        'video_views_to75': 'videoViewsTo75',
        'video_views_to95': 'videoViewsTo95',
        'video_views_to100': 'videoViewsTo100',
        'video_views_to3_sec': 'videoViewsTo3Sec',
        'video_views_to10_sec': 'videoViewsTo10Sec',
        'average_rate_video_viewed': 'averageRateVideoViewed',
        'average_duration_video_viewed': 'averageDurationVideoViewed',
        'impression_share': 'impressionShare',
        'budget_impression_share_lost_rate': 'budgetImpressionShareLostRate',
        'rank_impression_share_lost_rate': 'rankImpressionShareLostRate'
    }

    def __init__(self, imps=None, imps_prev=None, click_cnt=None, click_rate=None, click_rate_prev=None, cost=None, avg_cpc=None, conversions=None, conversion_rate=None, conversions_via_ad_click=None, conversion_rate_via_ad_click=None, all_conversions=None, all_conversion_rate=None, cpa=None, conversion_value=None, value_per_conversions=None, conv_value_per_cost=None, all_conv_value_per_cost=None, conv_value_via_ad_click_per_cost=None, all_conversion_value=None, value_per_all_conversions=None, conversion_value_via_ad_click=None, value_per_conversions_via_ad_click=None, cpa_via_ad_click=None, all_cpa=None, cross_device_conversions=None, avg_deliver_rank=None, measured_imps=None, total_vimps=None, measured_imps_rate=None, vimps=None, viewable_imps_rate=None, in_view_rate=None, viewable_clicks=None, in_view_click_cnt=None, viewable_click_rate=None, in_view_click_rate=None, paid_video_views=None, paid_video_view_rate=None, average_cpv=None, video_views=None, video_views_to25=None, video_views_to50=None, video_views_to75=None, video_views_to95=None, video_views_to100=None, video_views_to3_sec=None, video_views_to10_sec=None, average_rate_video_viewed=None, average_duration_video_viewed=None, impression_share=None, budget_impression_share_lost_rate=None, rank_impression_share_lost_rate=None, local_vars_configuration=None):  # noqa: E501
        """Stats - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._imps = None
        self._imps_prev = None
        self._click_cnt = None
        self._click_rate = None
        self._click_rate_prev = None
        self._cost = None
        self._avg_cpc = None
        self._conversions = None
        self._conversion_rate = None
        self._conversions_via_ad_click = None
        self._conversion_rate_via_ad_click = None
        self._all_conversions = None
        self._all_conversion_rate = None
        self._cpa = None
        self._conversion_value = None
        self._value_per_conversions = None
        self._conv_value_per_cost = None
        self._all_conv_value_per_cost = None
        self._conv_value_via_ad_click_per_cost = None
        self._all_conversion_value = None
        self._value_per_all_conversions = None
        self._conversion_value_via_ad_click = None
        self._value_per_conversions_via_ad_click = None
        self._cpa_via_ad_click = None
        self._all_cpa = None
        self._cross_device_conversions = None
        self._avg_deliver_rank = None
        self._measured_imps = None
        self._total_vimps = None
        self._measured_imps_rate = None
        self._vimps = None
        self._viewable_imps_rate = None
        self._in_view_rate = None
        self._viewable_clicks = None
        self._in_view_click_cnt = None
        self._viewable_click_rate = None
        self._in_view_click_rate = None
        self._paid_video_views = None
        self._paid_video_view_rate = None
        self._average_cpv = None
        self._video_views = None
        self._video_views_to25 = None
        self._video_views_to50 = None
        self._video_views_to75 = None
        self._video_views_to95 = None
        self._video_views_to100 = None
        self._video_views_to3_sec = None
        self._video_views_to10_sec = None
        self._average_rate_video_viewed = None
        self._average_duration_video_viewed = None
        self._impression_share = None
        self._budget_impression_share_lost_rate = None
        self._rank_impression_share_lost_rate = None
        self.discriminator = None

        self.imps = imps
        self.imps_prev = imps_prev
        self.click_cnt = click_cnt
        self.click_rate = click_rate
        self.click_rate_prev = click_rate_prev
        self.cost = cost
        self.avg_cpc = avg_cpc
        self.conversions = conversions
        self.conversion_rate = conversion_rate
        self.conversions_via_ad_click = conversions_via_ad_click
        self.conversion_rate_via_ad_click = conversion_rate_via_ad_click
        self.all_conversions = all_conversions
        self.all_conversion_rate = all_conversion_rate
        self.cpa = cpa
        self.conversion_value = conversion_value
        self.value_per_conversions = value_per_conversions
        self.conv_value_per_cost = conv_value_per_cost
        self.all_conv_value_per_cost = all_conv_value_per_cost
        self.conv_value_via_ad_click_per_cost = conv_value_via_ad_click_per_cost
        self.all_conversion_value = all_conversion_value
        self.value_per_all_conversions = value_per_all_conversions
        self.conversion_value_via_ad_click = conversion_value_via_ad_click
        self.value_per_conversions_via_ad_click = value_per_conversions_via_ad_click
        self.cpa_via_ad_click = cpa_via_ad_click
        self.all_cpa = all_cpa
        self.cross_device_conversions = cross_device_conversions
        self.avg_deliver_rank = avg_deliver_rank
        self.measured_imps = measured_imps
        self.total_vimps = total_vimps
        self.measured_imps_rate = measured_imps_rate
        self.vimps = vimps
        self.viewable_imps_rate = viewable_imps_rate
        self.in_view_rate = in_view_rate
        self.viewable_clicks = viewable_clicks
        self.in_view_click_cnt = in_view_click_cnt
        self.viewable_click_rate = viewable_click_rate
        self.in_view_click_rate = in_view_click_rate
        self.paid_video_views = paid_video_views
        self.paid_video_view_rate = paid_video_view_rate
        self.average_cpv = average_cpv
        self.video_views = video_views
        self.video_views_to25 = video_views_to25
        self.video_views_to50 = video_views_to50
        self.video_views_to75 = video_views_to75
        self.video_views_to95 = video_views_to95
        self.video_views_to100 = video_views_to100
        self.video_views_to3_sec = video_views_to3_sec
        self.video_views_to10_sec = video_views_to10_sec
        self.average_rate_video_viewed = average_rate_video_viewed
        self.average_duration_video_viewed = average_duration_video_viewed
        self.impression_share = impression_share
        self.budget_impression_share_lost_rate = budget_impression_share_lost_rate
        self.rank_impression_share_lost_rate = rank_impression_share_lost_rate

    @property
    def imps(self):
        """Gets the imps of this Stats.  # noqa: E501

        <div lang=\"ja\">インプレッション数</div> <div lang=\"en\">Number of impressions</div>   # noqa: E501

        :return: The imps of this Stats.  # noqa: E501
        :rtype: int
        """
        return self._imps

    @imps.setter
    def imps(self, imps):
        """Sets the imps of this Stats.

        <div lang=\"ja\">インプレッション数</div> <div lang=\"en\">Number of impressions</div>   # noqa: E501

        :param imps: The imps of this Stats.  # noqa: E501
        :type: int
        """

        self._imps = imps

    @property
    def imps_prev(self):
        """Gets the imps_prev of this Stats.  # noqa: E501

        <div lang=\"ja\">インプレッション数（旧）</div> <div lang=\"en\">Impressions (previous)</div>   # noqa: E501

        :return: The imps_prev of this Stats.  # noqa: E501
        :rtype: float
        """
        return self._imps_prev

    @imps_prev.setter
    def imps_prev(self, imps_prev):
        """Sets the imps_prev of this Stats.

        <div lang=\"ja\">インプレッション数（旧）</div> <div lang=\"en\">Impressions (previous)</div>   # noqa: E501

        :param imps_prev: The imps_prev of this Stats.  # noqa: E501
        :type: float
        """

        self._imps_prev = imps_prev

    @property
    def click_cnt(self):
        """Gets the click_cnt of this Stats.  # noqa: E501

        <div lang=\"ja\">クリック数</div> <div lang=\"en\">Number of clicks</div>   # noqa: E501

        :return: The click_cnt of this Stats.  # noqa: E501
        :rtype: int
        """
        return self._click_cnt

    @click_cnt.setter
    def click_cnt(self, click_cnt):
        """Sets the click_cnt of this Stats.

        <div lang=\"ja\">クリック数</div> <div lang=\"en\">Number of clicks</div>   # noqa: E501

        :param click_cnt: The click_cnt of this Stats.  # noqa: E501
        :type: int
        """

        self._click_cnt = click_cnt

    @property
    def click_rate(self):
        """Gets the click_rate of this Stats.  # noqa: E501

        <div lang=\"ja\">クリック率</div> <div lang=\"en\">Click through rate</div>   # noqa: E501

        :return: The click_rate of this Stats.  # noqa: E501
        :rtype: float
        """
        return self._click_rate

    @click_rate.setter
    def click_rate(self, click_rate):
        """Sets the click_rate of this Stats.

        <div lang=\"ja\">クリック率</div> <div lang=\"en\">Click through rate</div>   # noqa: E501

        :param click_rate: The click_rate of this Stats.  # noqa: E501
        :type: float
        """

        self._click_rate = click_rate

    @property
    def click_rate_prev(self):
        """Gets the click_rate_prev of this Stats.  # noqa: E501

        <div lang=\"ja\">クリック率（旧）</div> <div lang=\"en\">CTR (previous)</div>   # noqa: E501

        :return: The click_rate_prev of this Stats.  # noqa: E501
        :rtype: float
        """
        return self._click_rate_prev

    @click_rate_prev.setter
    def click_rate_prev(self, click_rate_prev):
        """Sets the click_rate_prev of this Stats.

        <div lang=\"ja\">クリック率（旧）</div> <div lang=\"en\">CTR (previous)</div>   # noqa: E501

        :param click_rate_prev: The click_rate_prev of this Stats.  # noqa: E501
        :type: float
        """

        self._click_rate_prev = click_rate_prev

    @property
    def cost(self):
        """Gets the cost of this Stats.  # noqa: E501

        <div lang=\"ja\">コスト</div> <div lang=\"en\">Cost</div>   # noqa: E501

        :return: The cost of this Stats.  # noqa: E501
        :rtype: float
        """
        return self._cost

    @cost.setter
    def cost(self, cost):
        """Sets the cost of this Stats.

        <div lang=\"ja\">コスト</div> <div lang=\"en\">Cost</div>   # noqa: E501

        :param cost: The cost of this Stats.  # noqa: E501
        :type: float
        """

        self._cost = cost

    @property
    def avg_cpc(self):
        """Gets the avg_cpc of this Stats.  # noqa: E501

        <div lang=\"ja\">平均CPC</div> <div lang=\"en\">Avg. CPC</div>   # noqa: E501

        :return: The avg_cpc of this Stats.  # noqa: E501
        :rtype: float
        """
        return self._avg_cpc

    @avg_cpc.setter
    def avg_cpc(self, avg_cpc):
        """Sets the avg_cpc of this Stats.

        <div lang=\"ja\">平均CPC</div> <div lang=\"en\">Avg. CPC</div>   # noqa: E501

        :param avg_cpc: The avg_cpc of this Stats.  # noqa: E501
        :type: float
        """

        self._avg_cpc = avg_cpc

    @property
    def conversions(self):
        """Gets the conversions of this Stats.  # noqa: E501

        <div lang=\"ja\">コンバージョン数</div> <div lang=\"en\">Conversions</div>   # noqa: E501

        :return: The conversions of this Stats.  # noqa: E501
        :rtype: int
        """
        return self._conversions

    @conversions.setter
    def conversions(self, conversions):
        """Sets the conversions of this Stats.

        <div lang=\"ja\">コンバージョン数</div> <div lang=\"en\">Conversions</div>   # noqa: E501

        :param conversions: The conversions of this Stats.  # noqa: E501
        :type: int
        """

        self._conversions = conversions

    @property
    def conversion_rate(self):
        """Gets the conversion_rate of this Stats.  # noqa: E501

        <div lang=\"ja\">コンバージョン率</div> <div lang=\"en\">Conv. rate</div>   # noqa: E501

        :return: The conversion_rate of this Stats.  # noqa: E501
        :rtype: float
        """
        return self._conversion_rate

    @conversion_rate.setter
    def conversion_rate(self, conversion_rate):
        """Sets the conversion_rate of this Stats.

        <div lang=\"ja\">コンバージョン率</div> <div lang=\"en\">Conv. rate</div>   # noqa: E501

        :param conversion_rate: The conversion_rate of this Stats.  # noqa: E501
        :type: float
        """

        self._conversion_rate = conversion_rate

    @property
    def conversions_via_ad_click(self):
        """Gets the conversions_via_ad_click of this Stats.  # noqa: E501

        <div lang=\"ja\">コンバージョン数（クリック経由）</div> <div lang=\"en\">Conversions (via click)</div>   # noqa: E501

        :return: The conversions_via_ad_click of this Stats.  # noqa: E501
        :rtype: int
        """
        return self._conversions_via_ad_click

    @conversions_via_ad_click.setter
    def conversions_via_ad_click(self, conversions_via_ad_click):
        """Sets the conversions_via_ad_click of this Stats.

        <div lang=\"ja\">コンバージョン数（クリック経由）</div> <div lang=\"en\">Conversions (via click)</div>   # noqa: E501

        :param conversions_via_ad_click: The conversions_via_ad_click of this Stats.  # noqa: E501
        :type: int
        """

        self._conversions_via_ad_click = conversions_via_ad_click

    @property
    def conversion_rate_via_ad_click(self):
        """Gets the conversion_rate_via_ad_click of this Stats.  # noqa: E501

        <div lang=\"ja\">コンバージョン率（クリック経由）</div> <div lang=\"en\">Conv. rate (via click)</div>   # noqa: E501

        :return: The conversion_rate_via_ad_click of this Stats.  # noqa: E501
        :rtype: float
        """
        return self._conversion_rate_via_ad_click

    @conversion_rate_via_ad_click.setter
    def conversion_rate_via_ad_click(self, conversion_rate_via_ad_click):
        """Sets the conversion_rate_via_ad_click of this Stats.

        <div lang=\"ja\">コンバージョン率（クリック経由）</div> <div lang=\"en\">Conv. rate (via click)</div>   # noqa: E501

        :param conversion_rate_via_ad_click: The conversion_rate_via_ad_click of this Stats.  # noqa: E501
        :type: float
        """

        self._conversion_rate_via_ad_click = conversion_rate_via_ad_click

    @property
    def all_conversions(self):
        """Gets the all_conversions of this Stats.  # noqa: E501

        <div lang=\"ja\">コンバージョン数（全て）</div> <div lang=\"en\">Conversions (all)</div>   # noqa: E501

        :return: The all_conversions of this Stats.  # noqa: E501
        :rtype: int
        """
        return self._all_conversions

    @all_conversions.setter
    def all_conversions(self, all_conversions):
        """Sets the all_conversions of this Stats.

        <div lang=\"ja\">コンバージョン数（全て）</div> <div lang=\"en\">Conversions (all)</div>   # noqa: E501

        :param all_conversions: The all_conversions of this Stats.  # noqa: E501
        :type: int
        """

        self._all_conversions = all_conversions

    @property
    def all_conversion_rate(self):
        """Gets the all_conversion_rate of this Stats.  # noqa: E501

        <div lang=\"ja\">コンバージョン率（全て）</div> <div lang=\"en\">Conv. rate (all)</div>   # noqa: E501

        :return: The all_conversion_rate of this Stats.  # noqa: E501
        :rtype: float
        """
        return self._all_conversion_rate

    @all_conversion_rate.setter
    def all_conversion_rate(self, all_conversion_rate):
        """Sets the all_conversion_rate of this Stats.

        <div lang=\"ja\">コンバージョン率（全て）</div> <div lang=\"en\">Conv. rate (all)</div>   # noqa: E501

        :param all_conversion_rate: The all_conversion_rate of this Stats.  # noqa: E501
        :type: float
        """

        self._all_conversion_rate = all_conversion_rate

    @property
    def cpa(self):
        """Gets the cpa of this Stats.  # noqa: E501

        <div lang=\"ja\">コンバージョン単価</div> <div lang=\"en\">Conversion cost per acquisition</div>   # noqa: E501

        :return: The cpa of this Stats.  # noqa: E501
        :rtype: str
        """
        return self._cpa

    @cpa.setter
    def cpa(self, cpa):
        """Sets the cpa of this Stats.

        <div lang=\"ja\">コンバージョン単価</div> <div lang=\"en\">Conversion cost per acquisition</div>   # noqa: E501

        :param cpa: The cpa of this Stats.  # noqa: E501
        :type: str
        """

        self._cpa = cpa

    @property
    def conversion_value(self):
        """Gets the conversion_value of this Stats.  # noqa: E501

        <div lang=\"ja\">コンバージョンの価値</div> <div lang=\"en\">Conv. value</div>   # noqa: E501

        :return: The conversion_value of this Stats.  # noqa: E501
        :rtype: str
        """
        return self._conversion_value

    @conversion_value.setter
    def conversion_value(self, conversion_value):
        """Sets the conversion_value of this Stats.

        <div lang=\"ja\">コンバージョンの価値</div> <div lang=\"en\">Conv. value</div>   # noqa: E501

        :param conversion_value: The conversion_value of this Stats.  # noqa: E501
        :type: str
        """

        self._conversion_value = conversion_value

    @property
    def value_per_conversions(self):
        """Gets the value_per_conversions of this Stats.  # noqa: E501

        <div lang=\"ja\">コンバージョンの価値/コンバージョン数</div> <div lang=\"en\">Conv. value/conv.</div>   # noqa: E501

        :return: The value_per_conversions of this Stats.  # noqa: E501
        :rtype: str
        """
        return self._value_per_conversions

    @value_per_conversions.setter
    def value_per_conversions(self, value_per_conversions):
        """Sets the value_per_conversions of this Stats.

        <div lang=\"ja\">コンバージョンの価値/コンバージョン数</div> <div lang=\"en\">Conv. value/conv.</div>   # noqa: E501

        :param value_per_conversions: The value_per_conversions of this Stats.  # noqa: E501
        :type: str
        """

        self._value_per_conversions = value_per_conversions

    @property
    def conv_value_per_cost(self):
        """Gets the conv_value_per_cost of this Stats.  # noqa: E501

        <div lang=\"ja\">コンバージョンの価値（クリック経由）/コスト</div> <div lang=\"en\">Conversions value/cost</div>   # noqa: E501

        :return: The conv_value_per_cost of this Stats.  # noqa: E501
        :rtype: float
        """
        return self._conv_value_per_cost

    @conv_value_per_cost.setter
    def conv_value_per_cost(self, conv_value_per_cost):
        """Sets the conv_value_per_cost of this Stats.

        <div lang=\"ja\">コンバージョンの価値（クリック経由）/コスト</div> <div lang=\"en\">Conversions value/cost</div>   # noqa: E501

        :param conv_value_per_cost: The conv_value_per_cost of this Stats.  # noqa: E501
        :type: float
        """

        self._conv_value_per_cost = conv_value_per_cost

    @property
    def all_conv_value_per_cost(self):
        """Gets the all_conv_value_per_cost of this Stats.  # noqa: E501

        <div lang=\"ja\">コンバージョンの価値（全て）/コスト</div> <div lang=\"en\">Conv. value (all)/cost All Conv.</div>   # noqa: E501

        :return: The all_conv_value_per_cost of this Stats.  # noqa: E501
        :rtype: float
        """
        return self._all_conv_value_per_cost

    @all_conv_value_per_cost.setter
    def all_conv_value_per_cost(self, all_conv_value_per_cost):
        """Sets the all_conv_value_per_cost of this Stats.

        <div lang=\"ja\">コンバージョンの価値（全て）/コスト</div> <div lang=\"en\">Conv. value (all)/cost All Conv.</div>   # noqa: E501

        :param all_conv_value_per_cost: The all_conv_value_per_cost of this Stats.  # noqa: E501
        :type: float
        """

        self._all_conv_value_per_cost = all_conv_value_per_cost

    @property
    def conv_value_via_ad_click_per_cost(self):
        """Gets the conv_value_via_ad_click_per_cost of this Stats.  # noqa: E501

        <div lang=\"ja\">コンバージョンの価値（クリック経由）/コスト</div> <div lang=\"en\">Conversions value(via ad clicks)/cost</div>   # noqa: E501

        :return: The conv_value_via_ad_click_per_cost of this Stats.  # noqa: E501
        :rtype: float
        """
        return self._conv_value_via_ad_click_per_cost

    @conv_value_via_ad_click_per_cost.setter
    def conv_value_via_ad_click_per_cost(self, conv_value_via_ad_click_per_cost):
        """Sets the conv_value_via_ad_click_per_cost of this Stats.

        <div lang=\"ja\">コンバージョンの価値（クリック経由）/コスト</div> <div lang=\"en\">Conversions value(via ad clicks)/cost</div>   # noqa: E501

        :param conv_value_via_ad_click_per_cost: The conv_value_via_ad_click_per_cost of this Stats.  # noqa: E501
        :type: float
        """

        self._conv_value_via_ad_click_per_cost = conv_value_via_ad_click_per_cost

    @property
    def all_conversion_value(self):
        """Gets the all_conversion_value of this Stats.  # noqa: E501

        <div lang=\"ja\">コンバージョンの価値（全て）</div> <div lang=\"en\">Conv. value (all)</div>   # noqa: E501

        :return: The all_conversion_value of this Stats.  # noqa: E501
        :rtype: str
        """
        return self._all_conversion_value

    @all_conversion_value.setter
    def all_conversion_value(self, all_conversion_value):
        """Sets the all_conversion_value of this Stats.

        <div lang=\"ja\">コンバージョンの価値（全て）</div> <div lang=\"en\">Conv. value (all)</div>   # noqa: E501

        :param all_conversion_value: The all_conversion_value of this Stats.  # noqa: E501
        :type: str
        """

        self._all_conversion_value = all_conversion_value

    @property
    def value_per_all_conversions(self):
        """Gets the value_per_all_conversions of this Stats.  # noqa: E501

        <div lang=\"ja\">コンバージョンの価値（全て）/コンバージョン数（全て）</div> <div lang=\"en\">Conv. value (all)/conv. (all)</div>   # noqa: E501

        :return: The value_per_all_conversions of this Stats.  # noqa: E501
        :rtype: str
        """
        return self._value_per_all_conversions

    @value_per_all_conversions.setter
    def value_per_all_conversions(self, value_per_all_conversions):
        """Sets the value_per_all_conversions of this Stats.

        <div lang=\"ja\">コンバージョンの価値（全て）/コンバージョン数（全て）</div> <div lang=\"en\">Conv. value (all)/conv. (all)</div>   # noqa: E501

        :param value_per_all_conversions: The value_per_all_conversions of this Stats.  # noqa: E501
        :type: str
        """

        self._value_per_all_conversions = value_per_all_conversions

    @property
    def conversion_value_via_ad_click(self):
        """Gets the conversion_value_via_ad_click of this Stats.  # noqa: E501

        <div lang=\"ja\">コンバージョンの価値（クリック経由）</div> <div lang=\"en\">Conv. value (via click)</div>   # noqa: E501

        :return: The conversion_value_via_ad_click of this Stats.  # noqa: E501
        :rtype: str
        """
        return self._conversion_value_via_ad_click

    @conversion_value_via_ad_click.setter
    def conversion_value_via_ad_click(self, conversion_value_via_ad_click):
        """Sets the conversion_value_via_ad_click of this Stats.

        <div lang=\"ja\">コンバージョンの価値（クリック経由）</div> <div lang=\"en\">Conv. value (via click)</div>   # noqa: E501

        :param conversion_value_via_ad_click: The conversion_value_via_ad_click of this Stats.  # noqa: E501
        :type: str
        """

        self._conversion_value_via_ad_click = conversion_value_via_ad_click

    @property
    def value_per_conversions_via_ad_click(self):
        """Gets the value_per_conversions_via_ad_click of this Stats.  # noqa: E501

        <div lang=\"ja\">コンバージョンの価値（クリック経由）/コンバージョン数（クリック経由）</div> <div lang=\"en\">Conv. value (via click)/conv. (via click)</div>   # noqa: E501

        :return: The value_per_conversions_via_ad_click of this Stats.  # noqa: E501
        :rtype: str
        """
        return self._value_per_conversions_via_ad_click

    @value_per_conversions_via_ad_click.setter
    def value_per_conversions_via_ad_click(self, value_per_conversions_via_ad_click):
        """Sets the value_per_conversions_via_ad_click of this Stats.

        <div lang=\"ja\">コンバージョンの価値（クリック経由）/コンバージョン数（クリック経由）</div> <div lang=\"en\">Conv. value (via click)/conv. (via click)</div>   # noqa: E501

        :param value_per_conversions_via_ad_click: The value_per_conversions_via_ad_click of this Stats.  # noqa: E501
        :type: str
        """

        self._value_per_conversions_via_ad_click = value_per_conversions_via_ad_click

    @property
    def cpa_via_ad_click(self):
        """Gets the cpa_via_ad_click of this Stats.  # noqa: E501

        <div lang=\"ja\">コスト/コンバージョン数（クリック経由）</div> <div lang=\"en\">Cost/conv. (via click)</div>   # noqa: E501

        :return: The cpa_via_ad_click of this Stats.  # noqa: E501
        :rtype: str
        """
        return self._cpa_via_ad_click

    @cpa_via_ad_click.setter
    def cpa_via_ad_click(self, cpa_via_ad_click):
        """Sets the cpa_via_ad_click of this Stats.

        <div lang=\"ja\">コスト/コンバージョン数（クリック経由）</div> <div lang=\"en\">Cost/conv. (via click)</div>   # noqa: E501

        :param cpa_via_ad_click: The cpa_via_ad_click of this Stats.  # noqa: E501
        :type: str
        """

        self._cpa_via_ad_click = cpa_via_ad_click

    @property
    def all_cpa(self):
        """Gets the all_cpa of this Stats.  # noqa: E501

        <div lang=\"ja\">コスト/コンバージョン数（全て）</div> <div lang=\"en\">Cost/conv. (all)</div>   # noqa: E501

        :return: The all_cpa of this Stats.  # noqa: E501
        :rtype: str
        """
        return self._all_cpa

    @all_cpa.setter
    def all_cpa(self, all_cpa):
        """Sets the all_cpa of this Stats.

        <div lang=\"ja\">コスト/コンバージョン数（全て）</div> <div lang=\"en\">Cost/conv. (all)</div>   # noqa: E501

        :param all_cpa: The all_cpa of this Stats.  # noqa: E501
        :type: str
        """

        self._all_cpa = all_cpa

    @property
    def cross_device_conversions(self):
        """Gets the cross_device_conversions of this Stats.  # noqa: E501

        <div lang=\"ja\">クロスデバイスコンバージョン数</div> <div lang=\"en\">Cross-device conv.</div>   # noqa: E501

        :return: The cross_device_conversions of this Stats.  # noqa: E501
        :rtype: int
        """
        return self._cross_device_conversions

    @cross_device_conversions.setter
    def cross_device_conversions(self, cross_device_conversions):
        """Sets the cross_device_conversions of this Stats.

        <div lang=\"ja\">クロスデバイスコンバージョン数</div> <div lang=\"en\">Cross-device conv.</div>   # noqa: E501

        :param cross_device_conversions: The cross_device_conversions of this Stats.  # noqa: E501
        :type: int
        """

        self._cross_device_conversions = cross_device_conversions

    @property
    def avg_deliver_rank(self):
        """Gets the avg_deliver_rank of this Stats.  # noqa: E501

        <div lang=\"ja\">平均掲載順位（配信された時のeCPM順位の平均）</div> <div lang=\"en\">Avg. position (the average of eCPM rank on ads delivery)</div>   # noqa: E501

        :return: The avg_deliver_rank of this Stats.  # noqa: E501
        :rtype: float
        """
        return self._avg_deliver_rank

    @avg_deliver_rank.setter
    def avg_deliver_rank(self, avg_deliver_rank):
        """Sets the avg_deliver_rank of this Stats.

        <div lang=\"ja\">平均掲載順位（配信された時のeCPM順位の平均）</div> <div lang=\"en\">Avg. position (the average of eCPM rank on ads delivery)</div>   # noqa: E501

        :param avg_deliver_rank: The avg_deliver_rank of this Stats.  # noqa: E501
        :type: float
        """

        self._avg_deliver_rank = avg_deliver_rank

    @property
    def measured_imps(self):
        """Gets the measured_imps of this Stats.  # noqa: E501

        <div lang=\"ja\">メジャードインプレッション数</div> <div lang=\"en\">Measured impressions</div>   # noqa: E501

        :return: The measured_imps of this Stats.  # noqa: E501
        :rtype: float
        """
        return self._measured_imps

    @measured_imps.setter
    def measured_imps(self, measured_imps):
        """Sets the measured_imps of this Stats.

        <div lang=\"ja\">メジャードインプレッション数</div> <div lang=\"en\">Measured impressions</div>   # noqa: E501

        :param measured_imps: The measured_imps of this Stats.  # noqa: E501
        :type: float
        """

        self._measured_imps = measured_imps

    @property
    def total_vimps(self):
        """Gets the total_vimps of this Stats.  # noqa: E501

        <div lang=\"ja\">メジャードインプレッション数（旧）</div> <div lang=\"en\">Measured impressions (previous)</div>   # noqa: E501

        :return: The total_vimps of this Stats.  # noqa: E501
        :rtype: int
        """
        return self._total_vimps

    @total_vimps.setter
    def total_vimps(self, total_vimps):
        """Sets the total_vimps of this Stats.

        <div lang=\"ja\">メジャードインプレッション数（旧）</div> <div lang=\"en\">Measured impressions (previous)</div>   # noqa: E501

        :param total_vimps: The total_vimps of this Stats.  # noqa: E501
        :type: int
        """

        self._total_vimps = total_vimps

    @property
    def measured_imps_rate(self):
        """Gets the measured_imps_rate of this Stats.  # noqa: E501

        <div lang=\"ja\">メジャードインプレッション測定率</div> <div lang=\"en\">Measured impression rate</div>   # noqa: E501

        :return: The measured_imps_rate of this Stats.  # noqa: E501
        :rtype: float
        """
        return self._measured_imps_rate

    @measured_imps_rate.setter
    def measured_imps_rate(self, measured_imps_rate):
        """Sets the measured_imps_rate of this Stats.

        <div lang=\"ja\">メジャードインプレッション測定率</div> <div lang=\"en\">Measured impression rate</div>   # noqa: E501

        :param measured_imps_rate: The measured_imps_rate of this Stats.  # noqa: E501
        :type: float
        """

        self._measured_imps_rate = measured_imps_rate

    @property
    def vimps(self):
        """Gets the vimps of this Stats.  # noqa: E501

        <div lang=\"ja\">ビューアブルインプレッション数</div> <div lang=\"en\">Viewable impressions</div>   # noqa: E501

        :return: The vimps of this Stats.  # noqa: E501
        :rtype: int
        """
        return self._vimps

    @vimps.setter
    def vimps(self, vimps):
        """Sets the vimps of this Stats.

        <div lang=\"ja\">ビューアブルインプレッション数</div> <div lang=\"en\">Viewable impressions</div>   # noqa: E501

        :param vimps: The vimps of this Stats.  # noqa: E501
        :type: int
        """

        self._vimps = vimps

    @property
    def viewable_imps_rate(self):
        """Gets the viewable_imps_rate of this Stats.  # noqa: E501

        <div lang=\"ja\">ビューアブルインプレッション率</div> <div lang=\"en\">Viewable impression rate</div>   # noqa: E501

        :return: The viewable_imps_rate of this Stats.  # noqa: E501
        :rtype: float
        """
        return self._viewable_imps_rate

    @viewable_imps_rate.setter
    def viewable_imps_rate(self, viewable_imps_rate):
        """Sets the viewable_imps_rate of this Stats.

        <div lang=\"ja\">ビューアブルインプレッション率</div> <div lang=\"en\">Viewable impression rate</div>   # noqa: E501

        :param viewable_imps_rate: The viewable_imps_rate of this Stats.  # noqa: E501
        :type: float
        """

        self._viewable_imps_rate = viewable_imps_rate

    @property
    def in_view_rate(self):
        """Gets the in_view_rate of this Stats.  # noqa: E501

        <div lang=\"ja\">ビューアブルインプレッション率（旧）</div> <div lang=\"en\">Viewable impression rate (previous)</div>   # noqa: E501

        :return: The in_view_rate of this Stats.  # noqa: E501
        :rtype: float
        """
        return self._in_view_rate

    @in_view_rate.setter
    def in_view_rate(self, in_view_rate):
        """Sets the in_view_rate of this Stats.

        <div lang=\"ja\">ビューアブルインプレッション率（旧）</div> <div lang=\"en\">Viewable impression rate (previous)</div>   # noqa: E501

        :param in_view_rate: The in_view_rate of this Stats.  # noqa: E501
        :type: float
        """

        self._in_view_rate = in_view_rate

    @property
    def viewable_clicks(self):
        """Gets the viewable_clicks of this Stats.  # noqa: E501

        <div lang=\"ja\">ビューアブルクリック数</div> <div lang=\"en\">Viewable clicks</div>   # noqa: E501

        :return: The viewable_clicks of this Stats.  # noqa: E501
        :rtype: float
        """
        return self._viewable_clicks

    @viewable_clicks.setter
    def viewable_clicks(self, viewable_clicks):
        """Sets the viewable_clicks of this Stats.

        <div lang=\"ja\">ビューアブルクリック数</div> <div lang=\"en\">Viewable clicks</div>   # noqa: E501

        :param viewable_clicks: The viewable_clicks of this Stats.  # noqa: E501
        :type: float
        """

        self._viewable_clicks = viewable_clicks

    @property
    def in_view_click_cnt(self):
        """Gets the in_view_click_cnt of this Stats.  # noqa: E501

        <div lang=\"ja\">ビューアブルクリック数（旧）</div> <div lang=\"en\">Viewable clicks (previous)</div>   # noqa: E501

        :return: The in_view_click_cnt of this Stats.  # noqa: E501
        :rtype: int
        """
        return self._in_view_click_cnt

    @in_view_click_cnt.setter
    def in_view_click_cnt(self, in_view_click_cnt):
        """Sets the in_view_click_cnt of this Stats.

        <div lang=\"ja\">ビューアブルクリック数（旧）</div> <div lang=\"en\">Viewable clicks (previous)</div>   # noqa: E501

        :param in_view_click_cnt: The in_view_click_cnt of this Stats.  # noqa: E501
        :type: int
        """

        self._in_view_click_cnt = in_view_click_cnt

    @property
    def viewable_click_rate(self):
        """Gets the viewable_click_rate of this Stats.  # noqa: E501

        <div lang=\"ja\">ビューアブルクリック率</div> <div lang=\"en\">Viewable CTR</div>   # noqa: E501

        :return: The viewable_click_rate of this Stats.  # noqa: E501
        :rtype: float
        """
        return self._viewable_click_rate

    @viewable_click_rate.setter
    def viewable_click_rate(self, viewable_click_rate):
        """Sets the viewable_click_rate of this Stats.

        <div lang=\"ja\">ビューアブルクリック率</div> <div lang=\"en\">Viewable CTR</div>   # noqa: E501

        :param viewable_click_rate: The viewable_click_rate of this Stats.  # noqa: E501
        :type: float
        """

        self._viewable_click_rate = viewable_click_rate

    @property
    def in_view_click_rate(self):
        """Gets the in_view_click_rate of this Stats.  # noqa: E501

        <div lang=\"ja\">ビューアブルクリック率（旧）</div> <div lang=\"en\">Viewable CTR (previous)</div>   # noqa: E501

        :return: The in_view_click_rate of this Stats.  # noqa: E501
        :rtype: float
        """
        return self._in_view_click_rate

    @in_view_click_rate.setter
    def in_view_click_rate(self, in_view_click_rate):
        """Sets the in_view_click_rate of this Stats.

        <div lang=\"ja\">ビューアブルクリック率（旧）</div> <div lang=\"en\">Viewable CTR (previous)</div>   # noqa: E501

        :param in_view_click_rate: The in_view_click_rate of this Stats.  # noqa: E501
        :type: float
        """

        self._in_view_click_rate = in_view_click_rate

    @property
    def paid_video_views(self):
        """Gets the paid_video_views of this Stats.  # noqa: E501

        <div lang=\"ja\">課金が発生した動画再生数 (CPV課金キャンペーンのみ)</div> <div lang=\"en\">Paid video views (CPV)</div>   # noqa: E501

        :return: The paid_video_views of this Stats.  # noqa: E501
        :rtype: int
        """
        return self._paid_video_views

    @paid_video_views.setter
    def paid_video_views(self, paid_video_views):
        """Sets the paid_video_views of this Stats.

        <div lang=\"ja\">課金が発生した動画再生数 (CPV課金キャンペーンのみ)</div> <div lang=\"en\">Paid video views (CPV)</div>   # noqa: E501

        :param paid_video_views: The paid_video_views of this Stats.  # noqa: E501
        :type: int
        """

        self._paid_video_views = paid_video_views

    @property
    def paid_video_view_rate(self):
        """Gets the paid_video_view_rate of this Stats.  # noqa: E501

        <div lang=\"ja\">課金が発生した動画再生率 (CPV課金キャンペーンのみ)</div> <div lang=\"en\">Paid video view rate (CPV)</div>   # noqa: E501

        :return: The paid_video_view_rate of this Stats.  # noqa: E501
        :rtype: float
        """
        return self._paid_video_view_rate

    @paid_video_view_rate.setter
    def paid_video_view_rate(self, paid_video_view_rate):
        """Sets the paid_video_view_rate of this Stats.

        <div lang=\"ja\">課金が発生した動画再生率 (CPV課金キャンペーンのみ)</div> <div lang=\"en\">Paid video view rate (CPV)</div>   # noqa: E501

        :param paid_video_view_rate: The paid_video_view_rate of this Stats.  # noqa: E501
        :type: float
        """

        self._paid_video_view_rate = paid_video_view_rate

    @property
    def average_cpv(self):
        """Gets the average_cpv of this Stats.  # noqa: E501

        <div lang=\"ja\">平均CPV</div> <div lang=\"en\">Avg. CPV</div>   # noqa: E501

        :return: The average_cpv of this Stats.  # noqa: E501
        :rtype: float
        """
        return self._average_cpv

    @average_cpv.setter
    def average_cpv(self, average_cpv):
        """Sets the average_cpv of this Stats.

        <div lang=\"ja\">平均CPV</div> <div lang=\"en\">Avg. CPV</div>   # noqa: E501

        :param average_cpv: The average_cpv of this Stats.  # noqa: E501
        :type: float
        """

        self._average_cpv = average_cpv

    @property
    def video_views(self):
        """Gets the video_views of this Stats.  # noqa: E501

        <div lang=\"ja\">動画の再生開始数</div> <div lang=\"en\">Video views</div>   # noqa: E501

        :return: The video_views of this Stats.  # noqa: E501
        :rtype: int
        """
        return self._video_views

    @video_views.setter
    def video_views(self, video_views):
        """Sets the video_views of this Stats.

        <div lang=\"ja\">動画の再生開始数</div> <div lang=\"en\">Video views</div>   # noqa: E501

        :param video_views: The video_views of this Stats.  # noqa: E501
        :type: int
        """

        self._video_views = video_views

    @property
    def video_views_to25(self):
        """Gets the video_views_to25 of this Stats.  # noqa: E501

        <div lang=\"ja\">動画の25％再生数</div> <div lang=\"en\">25% video views</div>   # noqa: E501

        :return: The video_views_to25 of this Stats.  # noqa: E501
        :rtype: int
        """
        return self._video_views_to25

    @video_views_to25.setter
    def video_views_to25(self, video_views_to25):
        """Sets the video_views_to25 of this Stats.

        <div lang=\"ja\">動画の25％再生数</div> <div lang=\"en\">25% video views</div>   # noqa: E501

        :param video_views_to25: The video_views_to25 of this Stats.  # noqa: E501
        :type: int
        """

        self._video_views_to25 = video_views_to25

    @property
    def video_views_to50(self):
        """Gets the video_views_to50 of this Stats.  # noqa: E501

        <div lang=\"ja\">動画の50％再生数</div> <div lang=\"en\">50% video views</div>   # noqa: E501

        :return: The video_views_to50 of this Stats.  # noqa: E501
        :rtype: int
        """
        return self._video_views_to50

    @video_views_to50.setter
    def video_views_to50(self, video_views_to50):
        """Sets the video_views_to50 of this Stats.

        <div lang=\"ja\">動画の50％再生数</div> <div lang=\"en\">50% video views</div>   # noqa: E501

        :param video_views_to50: The video_views_to50 of this Stats.  # noqa: E501
        :type: int
        """

        self._video_views_to50 = video_views_to50

    @property
    def video_views_to75(self):
        """Gets the video_views_to75 of this Stats.  # noqa: E501

        <div lang=\"ja\">動画の75％再生数</div> <div lang=\"en\">75% video views</div>   # noqa: E501

        :return: The video_views_to75 of this Stats.  # noqa: E501
        :rtype: int
        """
        return self._video_views_to75

    @video_views_to75.setter
    def video_views_to75(self, video_views_to75):
        """Sets the video_views_to75 of this Stats.

        <div lang=\"ja\">動画の75％再生数</div> <div lang=\"en\">75% video views</div>   # noqa: E501

        :param video_views_to75: The video_views_to75 of this Stats.  # noqa: E501
        :type: int
        """

        self._video_views_to75 = video_views_to75

    @property
    def video_views_to95(self):
        """Gets the video_views_to95 of this Stats.  # noqa: E501

        <div lang=\"ja\">動画の95％再生数</div> <div lang=\"en\">95% video views</div>   # noqa: E501

        :return: The video_views_to95 of this Stats.  # noqa: E501
        :rtype: int
        """
        return self._video_views_to95

    @video_views_to95.setter
    def video_views_to95(self, video_views_to95):
        """Sets the video_views_to95 of this Stats.

        <div lang=\"ja\">動画の95％再生数</div> <div lang=\"en\">95% video views</div>   # noqa: E501

        :param video_views_to95: The video_views_to95 of this Stats.  # noqa: E501
        :type: int
        """

        self._video_views_to95 = video_views_to95

    @property
    def video_views_to100(self):
        """Gets the video_views_to100 of this Stats.  # noqa: E501

        <div lang=\"ja\">動画の100％再生数</div> <div lang=\"en\">100% video views</div>   # noqa: E501

        :return: The video_views_to100 of this Stats.  # noqa: E501
        :rtype: int
        """
        return self._video_views_to100

    @video_views_to100.setter
    def video_views_to100(self, video_views_to100):
        """Sets the video_views_to100 of this Stats.

        <div lang=\"ja\">動画の100％再生数</div> <div lang=\"en\">100% video views</div>   # noqa: E501

        :param video_views_to100: The video_views_to100 of this Stats.  # noqa: E501
        :type: int
        """

        self._video_views_to100 = video_views_to100

    @property
    def video_views_to3_sec(self):
        """Gets the video_views_to3_sec of this Stats.  # noqa: E501

        <div lang=\"ja\">動画の3秒再生数</div> <div lang=\"en\">3 sec video views</div>   # noqa: E501

        :return: The video_views_to3_sec of this Stats.  # noqa: E501
        :rtype: int
        """
        return self._video_views_to3_sec

    @video_views_to3_sec.setter
    def video_views_to3_sec(self, video_views_to3_sec):
        """Sets the video_views_to3_sec of this Stats.

        <div lang=\"ja\">動画の3秒再生数</div> <div lang=\"en\">3 sec video views</div>   # noqa: E501

        :param video_views_to3_sec: The video_views_to3_sec of this Stats.  # noqa: E501
        :type: int
        """

        self._video_views_to3_sec = video_views_to3_sec

    @property
    def video_views_to10_sec(self):
        """Gets the video_views_to10_sec of this Stats.  # noqa: E501

        <div lang=\"ja\">動画の10秒再生数</div> <div lang=\"en\">10 sec video views</div>   # noqa: E501

        :return: The video_views_to10_sec of this Stats.  # noqa: E501
        :rtype: int
        """
        return self._video_views_to10_sec

    @video_views_to10_sec.setter
    def video_views_to10_sec(self, video_views_to10_sec):
        """Sets the video_views_to10_sec of this Stats.

        <div lang=\"ja\">動画の10秒再生数</div> <div lang=\"en\">10 sec video views</div>   # noqa: E501

        :param video_views_to10_sec: The video_views_to10_sec of this Stats.  # noqa: E501
        :type: int
        """

        self._video_views_to10_sec = video_views_to10_sec

    @property
    def average_rate_video_viewed(self):
        """Gets the average_rate_video_viewed of this Stats.  # noqa: E501

        <div lang=\"ja\">動画の平均再生開始率</div> <div lang=\"en\">Avg. video view rate</div>   # noqa: E501

        :return: The average_rate_video_viewed of this Stats.  # noqa: E501
        :rtype: float
        """
        return self._average_rate_video_viewed

    @average_rate_video_viewed.setter
    def average_rate_video_viewed(self, average_rate_video_viewed):
        """Sets the average_rate_video_viewed of this Stats.

        <div lang=\"ja\">動画の平均再生開始率</div> <div lang=\"en\">Avg. video view rate</div>   # noqa: E501

        :param average_rate_video_viewed: The average_rate_video_viewed of this Stats.  # noqa: E501
        :type: float
        """

        self._average_rate_video_viewed = average_rate_video_viewed

    @property
    def average_duration_video_viewed(self):
        """Gets the average_duration_video_viewed of this Stats.  # noqa: E501

        <div lang=\"ja\">動画の平均再生時間</div> <div lang=\"en\">Avg. duration of video viewed</div>   # noqa: E501

        :return: The average_duration_video_viewed of this Stats.  # noqa: E501
        :rtype: float
        """
        return self._average_duration_video_viewed

    @average_duration_video_viewed.setter
    def average_duration_video_viewed(self, average_duration_video_viewed):
        """Sets the average_duration_video_viewed of this Stats.

        <div lang=\"ja\">動画の平均再生時間</div> <div lang=\"en\">Avg. duration of video viewed</div>   # noqa: E501

        :param average_duration_video_viewed: The average_duration_video_viewed of this Stats.  # noqa: E501
        :type: float
        """

        self._average_duration_video_viewed = average_duration_video_viewed

    @property
    def impression_share(self):
        """Gets the impression_share of this Stats.  # noqa: E501

        <div lang=\"ja\">インプレッションシェア</div> <div lang=\"en\">Impression share</div>   # noqa: E501

        :return: The impression_share of this Stats.  # noqa: E501
        :rtype: float
        """
        return self._impression_share

    @impression_share.setter
    def impression_share(self, impression_share):
        """Sets the impression_share of this Stats.

        <div lang=\"ja\">インプレッションシェア</div> <div lang=\"en\">Impression share</div>   # noqa: E501

        :param impression_share: The impression_share of this Stats.  # noqa: E501
        :type: float
        """

        self._impression_share = impression_share

    @property
    def budget_impression_share_lost_rate(self):
        """Gets the budget_impression_share_lost_rate of this Stats.  # noqa: E501

        <div lang=\"ja\">インプレッションシェア損失率（予算）</div> <div lang=\"en\">Impression share lost rate(budget)</div>   # noqa: E501

        :return: The budget_impression_share_lost_rate of this Stats.  # noqa: E501
        :rtype: float
        """
        return self._budget_impression_share_lost_rate

    @budget_impression_share_lost_rate.setter
    def budget_impression_share_lost_rate(self, budget_impression_share_lost_rate):
        """Sets the budget_impression_share_lost_rate of this Stats.

        <div lang=\"ja\">インプレッションシェア損失率（予算）</div> <div lang=\"en\">Impression share lost rate(budget)</div>   # noqa: E501

        :param budget_impression_share_lost_rate: The budget_impression_share_lost_rate of this Stats.  # noqa: E501
        :type: float
        """

        self._budget_impression_share_lost_rate = budget_impression_share_lost_rate

    @property
    def rank_impression_share_lost_rate(self):
        """Gets the rank_impression_share_lost_rate of this Stats.  # noqa: E501

        <div lang=\"ja\">インプレッションシェア損失率（ランク）</div> <div lang=\"en\">Impression share lost rate(rank)</div>   # noqa: E501

        :return: The rank_impression_share_lost_rate of this Stats.  # noqa: E501
        :rtype: float
        """
        return self._rank_impression_share_lost_rate

    @rank_impression_share_lost_rate.setter
    def rank_impression_share_lost_rate(self, rank_impression_share_lost_rate):
        """Sets the rank_impression_share_lost_rate of this Stats.

        <div lang=\"ja\">インプレッションシェア損失率（ランク）</div> <div lang=\"en\">Impression share lost rate(rank)</div>   # noqa: E501

        :param rank_impression_share_lost_rate: The rank_impression_share_lost_rate of this Stats.  # noqa: E501
        :type: float
        """

        self._rank_impression_share_lost_rate = rank_impression_share_lost_rate

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Stats):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Stats):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Yahoo!広告 ディスプレイ広告 API リファレンス / Yahoo! Ads Display Ads API Reference

    <div lang=\"ja\">Yahoo!広告 ディスプレイ広告 APIのWebサービスについて説明します。<br> 「Try it out」のご利用には、事前にアプリケーションの登録が必要です。また、アプリケーションのリダイレクトURIの1つに<br> https://yahoojp-marketing.github.io/ads-display-api-documents/oauth2-redirect.htmlを登録してください。 </div> <div lang=\"en\">Display Ads API Web Services supported in Yahoo! Ads API.<br> When you use \"Try it out\", you need to register your application in advance.<br> As one of redirect URI for application, you need to set \"https://yahoojp-marketing.github.io/ads-display-api-documents/oauth2-redirect.html\". </div>   # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from yahoo_ads_display.configuration import Configuration


class SearchKeywordIdea(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'desktop_search_volume': 'int',
        'release_date': 'str',
        'search_keyword': 'str',
        'search_keyword_id': 'int',
        'smart_phone_search_volume': 'int',
        'tablet_search_volume': 'int'
    }

    attribute_map = {
        'desktop_search_volume': 'desktopSearchVolume',
        'release_date': 'releaseDate',
        'search_keyword': 'searchKeyword',
        'search_keyword_id': 'searchKeywordId',
        'smart_phone_search_volume': 'smartPhoneSearchVolume',
        'tablet_search_volume': 'tabletSearchVolume'
    }

    def __init__(self, desktop_search_volume=None, release_date=None, search_keyword=None, search_keyword_id=None, smart_phone_search_volume=None, tablet_search_volume=None, local_vars_configuration=None):  # noqa: E501
        """SearchKeywordIdea - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._desktop_search_volume = None
        self._release_date = None
        self._search_keyword = None
        self._search_keyword_id = None
        self._smart_phone_search_volume = None
        self._tablet_search_volume = None
        self.discriminator = None

        self.desktop_search_volume = desktop_search_volume
        self.release_date = release_date
        self.search_keyword = search_keyword
        self.search_keyword_id = search_keyword_id
        self.smart_phone_search_volume = smart_phone_search_volume
        self.tablet_search_volume = tablet_search_volume

    @property
    def desktop_search_volume(self):
        """Gets the desktop_search_volume of this SearchKeywordIdea.  # noqa: E501

        <div lang=\"ja\"> PCでのリーチ数です。<br> ※1000件未満の場合は<br> 0が取得されます。 </div> <div lang=\"en\"> Reach numbers on PC.<br> *If it is less than 1000 times, the value &#34;0&#34; will be responded. </div>   # noqa: E501

        :return: The desktop_search_volume of this SearchKeywordIdea.  # noqa: E501
        :rtype: int
        """
        return self._desktop_search_volume

    @desktop_search_volume.setter
    def desktop_search_volume(self, desktop_search_volume):
        """Sets the desktop_search_volume of this SearchKeywordIdea.

        <div lang=\"ja\"> PCでのリーチ数です。<br> ※1000件未満の場合は<br> 0が取得されます。 </div> <div lang=\"en\"> Reach numbers on PC.<br> *If it is less than 1000 times, the value &#34;0&#34; will be responded. </div>   # noqa: E501

        :param desktop_search_volume: The desktop_search_volume of this SearchKeywordIdea.  # noqa: E501
        :type: int
        """

        self._desktop_search_volume = desktop_search_volume

    @property
    def release_date(self):
        """Gets the release_date of this SearchKeywordIdea.  # noqa: E501

        <div lang=\"ja\">KW追加日(yyyy㎜dd)です。</div> <div lang=\"en\"> Additional date of keyword.<br> (yyyy㎜dd) </div>   # noqa: E501

        :return: The release_date of this SearchKeywordIdea.  # noqa: E501
        :rtype: str
        """
        return self._release_date

    @release_date.setter
    def release_date(self, release_date):
        """Sets the release_date of this SearchKeywordIdea.

        <div lang=\"ja\">KW追加日(yyyy㎜dd)です。</div> <div lang=\"en\"> Additional date of keyword.<br> (yyyy㎜dd) </div>   # noqa: E501

        :param release_date: The release_date of this SearchKeywordIdea.  # noqa: E501
        :type: str
        """

        self._release_date = release_date

    @property
    def search_keyword(self):
        """Gets the search_keyword of this SearchKeywordIdea.  # noqa: E501

        <div lang=\"ja\">サーチキーワードです。</div> <div lang=\"en\">Search keyword.</div>   # noqa: E501

        :return: The search_keyword of this SearchKeywordIdea.  # noqa: E501
        :rtype: str
        """
        return self._search_keyword

    @search_keyword.setter
    def search_keyword(self, search_keyword):
        """Sets the search_keyword of this SearchKeywordIdea.

        <div lang=\"ja\">サーチキーワードです。</div> <div lang=\"en\">Search keyword.</div>   # noqa: E501

        :param search_keyword: The search_keyword of this SearchKeywordIdea.  # noqa: E501
        :type: str
        """

        self._search_keyword = search_keyword

    @property
    def search_keyword_id(self):
        """Gets the search_keyword_id of this SearchKeywordIdea.  # noqa: E501

        <div lang=\"ja\">サーチキーワードIDです。</div> <div lang=\"en\">Search keyword ID.</div>   # noqa: E501

        :return: The search_keyword_id of this SearchKeywordIdea.  # noqa: E501
        :rtype: int
        """
        return self._search_keyword_id

    @search_keyword_id.setter
    def search_keyword_id(self, search_keyword_id):
        """Sets the search_keyword_id of this SearchKeywordIdea.

        <div lang=\"ja\">サーチキーワードIDです。</div> <div lang=\"en\">Search keyword ID.</div>   # noqa: E501

        :param search_keyword_id: The search_keyword_id of this SearchKeywordIdea.  # noqa: E501
        :type: int
        """

        self._search_keyword_id = search_keyword_id

    @property
    def smart_phone_search_volume(self):
        """Gets the smart_phone_search_volume of this SearchKeywordIdea.  # noqa: E501

        <div lang=\"ja\"> スマートフォンでのリーチ数です。<br> ※1000件未満の場合は<br> 0が取得されます。 </div> <div lang=\"en\"> Reach numbers on Smartphone.<br> *If it is less than 1000 times, the value &#34;0&#34; will be responded. </div>   # noqa: E501

        :return: The smart_phone_search_volume of this SearchKeywordIdea.  # noqa: E501
        :rtype: int
        """
        return self._smart_phone_search_volume

    @smart_phone_search_volume.setter
    def smart_phone_search_volume(self, smart_phone_search_volume):
        """Sets the smart_phone_search_volume of this SearchKeywordIdea.

        <div lang=\"ja\"> スマートフォンでのリーチ数です。<br> ※1000件未満の場合は<br> 0が取得されます。 </div> <div lang=\"en\"> Reach numbers on Smartphone.<br> *If it is less than 1000 times, the value &#34;0&#34; will be responded. </div>   # noqa: E501

        :param smart_phone_search_volume: The smart_phone_search_volume of this SearchKeywordIdea.  # noqa: E501
        :type: int
        """

        self._smart_phone_search_volume = smart_phone_search_volume

    @property
    def tablet_search_volume(self):
        """Gets the tablet_search_volume of this SearchKeywordIdea.  # noqa: E501

        <div lang=\"ja\"> タブレットでのリーチ数です。<br> ※1000件未満の場合は<br> 0が取得されます。 </div> <div lang=\"en\"> Reach numbers on Tablet.<br> *If it is less than 1000 times, the value &#34;0&#34; will be responded. </div>   # noqa: E501

        :return: The tablet_search_volume of this SearchKeywordIdea.  # noqa: E501
        :rtype: int
        """
        return self._tablet_search_volume

    @tablet_search_volume.setter
    def tablet_search_volume(self, tablet_search_volume):
        """Sets the tablet_search_volume of this SearchKeywordIdea.

        <div lang=\"ja\"> タブレットでのリーチ数です。<br> ※1000件未満の場合は<br> 0が取得されます。 </div> <div lang=\"en\"> Reach numbers on Tablet.<br> *If it is less than 1000 times, the value &#34;0&#34; will be responded. </div>   # noqa: E501

        :param tablet_search_volume: The tablet_search_volume of this SearchKeywordIdea.  # noqa: E501
        :type: int
        """

        self._tablet_search_volume = tablet_search_volume

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SearchKeywordIdea):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, SearchKeywordIdea):
            return True

        return self.to_dict() != other.to_dict()



from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from yahoo_ads_display.api.account_ad_product_service_api import AccountAdProductServiceApi
from yahoo_ads_display.api.account_service_api import AccountServiceApi
from yahoo_ads_display.api.ad_group_ad_label_service_api import AdGroupAdLabelServiceApi
from yahoo_ads_display.api.ad_group_ad_service_api import AdGroupAdServiceApi
from yahoo_ads_display.api.ad_group_label_service_api import AdGroupLabelServiceApi
from yahoo_ads_display.api.ad_group_service_api import AdGroupServiceApi
from yahoo_ads_display.api.ad_group_target_service_api import AdGroupTargetServiceApi
from yahoo_ads_display.api.audit_log_service_api import AuditLogServiceApi
from yahoo_ads_display.api.balance_service_api import BalanceServiceApi
from yahoo_ads_display.api.campaign_label_service_api import CampaignLabelServiceApi
from yahoo_ads_display.api.campaign_migration_service_api import CampaignMigrationServiceApi
from yahoo_ads_display.api.campaign_service_api import CampaignServiceApi
from yahoo_ads_display.api.conversion_tracker_service_api import ConversionTrackerServiceApi
from yahoo_ads_display.api.dictionary_service_api import DictionaryServiceApi
from yahoo_ads_display.api.feed_data_service_api import FeedDataServiceApi
from yahoo_ads_display.api.feed_ftp_request_service_api import FeedFtpRequestServiceApi
from yahoo_ads_display.api.feed_ftp_service_api import FeedFtpServiceApi
from yahoo_ads_display.api.feed_item_service_api import FeedItemServiceApi
from yahoo_ads_display.api.feed_service_api import FeedServiceApi
from yahoo_ads_display.api.feed_set_service_api import FeedSetServiceApi
from yahoo_ads_display.api.label_service_api import LabelServiceApi
from yahoo_ads_display.api.media_service_api import MediaServiceApi
from yahoo_ads_display.api.placement_url_idea_service_api import PlacementUrlIdeaServiceApi
from yahoo_ads_display.api.placement_url_list_service_api import PlacementUrlListServiceApi
from yahoo_ads_display.api.report_definition_service_api import ReportDefinitionServiceApi
from yahoo_ads_display.api.retargeting_list_service_api import RetargetingListServiceApi
from yahoo_ads_display.api.retargeting_tag_service_api import RetargetingTagServiceApi
from yahoo_ads_display.api.search_keyword_idea_service_api import SearchKeywordIdeaServiceApi
from yahoo_ads_display.api.search_keyword_list_service_api import SearchKeywordListServiceApi
from yahoo_ads_display.api.stats_service_api import StatsServiceApi
from yahoo_ads_display.api.video_service_api import VideoServiceApi



# coding: utf-8

"""
    Yahoo!広告 ディスプレイ広告 API リファレンス / Yahoo! Ads Display Ads API Reference

    <div lang=\"ja\">Yahoo!広告 ディスプレイ広告 APIのWebサービスについて説明します。<br> 「Try it out」のご利用には、事前にアプリケーションの登録が必要です。また、アプリケーションのリダイレクトURIの1つに<br> https://yahoojp-marketing.github.io/ads-display-api-documents/oauth2-redirect.htmlを登録してください。 </div> <div lang=\"en\">Display Ads API Web Services supported in Yahoo! Ads API.<br> When you use \"Try it out\", you need to register your application in advance.<br> As one of redirect URI for application, you need to set \"https://yahoojp-marketing.github.io/ads-display-api-documents/oauth2-redirect.html\". </div>   # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import yahoo_ads_display
from yahoo_ads_display.models.ad_group_target_service_value import AdGroupTargetServiceValue  # noqa: E501
from yahoo_ads_display.rest import ApiException

class TestAdGroupTargetServiceValue(unittest.TestCase):
    """AdGroupTargetServiceValue unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test AdGroupTargetServiceValue
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = yahoo_ads_display.models.ad_group_target_service_value.AdGroupTargetServiceValue()  # noqa: E501
        if include_optional :
            return AdGroupTargetServiceValue(
                ad_group_target_list = yahoo_ads_display.models.ad_group_target.AdGroupTarget(
                    account_id = 56,
                    ad_group_id = 56,
                    bid_multiplier = 1.337,
                    campaign_id = 56,
                    target = yahoo_ads_display.models.ad_group_target_service_target.AdGroupTargetServiceTarget(
                        ad_schedule_target = yahoo_ads_display.models.ad_group_target_service_ad_schedule_target.AdGroupTargetServiceAdScheduleTarget(
                            day_of_week = 'MONDAY',
                            end_hour = 56,
                            start_hour = 56, ),
                        age_target = yahoo_ads_display.models.ad_group_target_service_age_target.AdGroupTargetServiceAgeTarget(
                            age = 'GT_RANGE13_14',
                            estimate_flg = 'PAUSED', ),
                        app_target = yahoo_ads_display.models.ad_group_target_service_app_target.AdGroupTargetServiceAppTarget(
                            device_app_type = 'APP', ),
                        audience_category_target = yahoo_ads_display.models.ad_group_target_service_audience_category_target.AdGroupTargetServiceAudienceCategoryTarget(
                            audience_category_type = '0',
                            category_name_en = '0',
                            category_name_ja = '0', ),
                        carrier_target = yahoo_ads_display.models.ad_group_target_service_carrier_target.AdGroupTargetServiceCarrierTarget(
                            carrier_type = 'DOCOMO', ),
                        device_target = yahoo_ads_display.models.ad_group_target_service_device_target.AdGroupTargetServiceDeviceTarget(
                            device_type = 'DESKTOP', ),
                        gender_target = yahoo_ads_display.models.ad_group_target_service_gender_target.AdGroupTargetServiceGenderTarget(
                            gender = 'ST_MALE', ),
                        geo_target = yahoo_ads_display.models.ad_group_target_service_geo_target.AdGroupTargetServiceGeoTarget(
                            geo_name_en = '0',
                            geo_name_ja = '0', ),
                        interest_category_target = yahoo_ads_display.models.ad_group_target_service_interest_category_target.AdGroupTargetServiceInterestCategoryTarget(
                            category_full_name_en = '0',
                            category_full_name_ja = '0', ),
                        is_remove = True,
                        os_target = yahoo_ads_display.models.ad_group_target_service_os_target.AdGroupTargetServiceOsTarget(
                            device_os_type = 'IOS', ),
                        os_version_target = yahoo_ads_display.models.ad_group_target_service_os_version_target.AdGroupTargetServiceOsVersionTarget(
                            os_version = '0', ),
                        placement_target = yahoo_ads_display.models.ad_group_target_service_placement_target.AdGroupTargetServicePlacementTarget(
                            placement_url_list_name = '0',
                            placement_url_list_type = 'WHITE_LIST', ),
                        search_target = yahoo_ads_display.models.ad_group_target_service_search_target.AdGroupTargetServiceSearchTarget(
                            search_keyword_list_name = '0', ),
                        site_category_target = yahoo_ads_display.models.ad_group_target_service_site_category_target.AdGroupTargetServiceSiteCategoryTarget(
                            category_full_name_en = '0',
                            category_full_name_ja = '0', ),
                        site_retargeting_target = yahoo_ads_display.models.ad_group_target_service_site_retargeting_target.AdGroupTargetServiceSiteRetargetingTarget(
                            target_list_deliver_type = 'INCLUDE',
                            target_list_name = '0', ),
                        target_id = '0',
                        target_type = 'AD_SCHEDULE_TARGET', ), ),
                errors = [
                    yahoo_ads_display.models.error.Error(
                        code = '0',
                        message = '0',
                        details = [
                            yahoo_ads_display.models.error_detail.ErrorDetail(
                                request_key = '0',
                                request_value = '0', )
                            ], )
                    ],
                operation_succeeded = True
            )
        else :
            return AdGroupTargetServiceValue(
        )

    def testAdGroupTargetServiceValue(self):
        """Test AdGroupTargetServiceValue"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Yahoo!広告 ディスプレイ広告 API リファレンス / Yahoo! Ads Display Ads API Reference

    <div lang=\"ja\">Yahoo!広告 ディスプレイ広告 APIのWebサービスについて説明します。<br> 「Try it out」のご利用には、事前にアプリケーションの登録が必要です。また、アプリケーションのリダイレクトURIの1つに<br> https://yahoojp-marketing.github.io/ads-display-api-documents/oauth2-redirect.htmlを登録してください。 </div> <div lang=\"en\">Display Ads API Web Services supported in Yahoo! Ads API.<br> When you use \"Try it out\", you need to register your application in advance.<br> As one of redirect URI for application, you need to set \"https://yahoojp-marketing.github.io/ads-display-api-documents/oauth2-redirect.html\". </div>   # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import yahoo_ads_display
from yahoo_ads_display.models.campaign_service_return_value import CampaignServiceReturnValue  # noqa: E501
from yahoo_ads_display.rest import ApiException

class TestCampaignServiceReturnValue(unittest.TestCase):
    """CampaignServiceReturnValue unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test CampaignServiceReturnValue
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = yahoo_ads_display.models.campaign_service_return_value.CampaignServiceReturnValue()  # noqa: E501
        if include_optional :
            return CampaignServiceReturnValue(
                values = [
                    yahoo_ads_display.models.campaign_service_value.CampaignServiceValue(
                        campaign = yahoo_ads_display.models.campaign.Campaign(
                            account_id = 56,
                            ad_product_type = '0',
                            app_id = '0',
                            app_name = '0',
                            bidding_strategy = yahoo_ads_display.models.campaign_service_bidding_strategy.CampaignServiceBiddingStrategy(
                                bidding_strategy_type = 'MANUAL_CPC', ),
                            budget = yahoo_ads_display.models.campaign_service_budget.CampaignServiceBudget(
                                amount = 56,
                                budget_delivery_method = 'STANDARD', ),
                            campaign_bidding_strategy = yahoo_ads_display.models.campaign_service_campaign_bidding_strategy.CampaignServiceCampaignBiddingStrategy(
                                campaign_bidding_strategy_type = 'AUTO',
                                max_cpc_bid_value = 56,
                                max_cpv_bid_value = 56,
                                max_vcpm_bid_value = 56,
                                target_cpa_bid_value = 56, ),
                            campaign_goal = '0',
                            campaign_id = 56,
                            campaign_name = '0',
                            conversion_optimizer = yahoo_ads_display.models.campaign_service_conversion_optimizer.CampaignServiceConversionOptimizer(
                                auto_campaign_conversion_optimizer = yahoo_ads_display.models.campaign_service_auto_campaign_conversion_optimizer.CampaignServiceAutoCampaignConversionOptimizer(
                                    conversion_optimizer_eligibility_flg = 'ENABLE',
                                    target_cpa = 56, ),
                                conversion_optimizer_type = 'MANUAL',
                                manual_campaign_conversion_optimizer = yahoo_ads_display.models.campaign_service_manual_campaign_conversion_optimizer.CampaignServiceManualCampaignConversionOptimizer(
                                    conversion_optimizer_training_status = 'PROCESSING', ), ),
                            device_os_type = 'ANDROID',
                            end_date = '0',
                            feed_id = 56,
                            frequency_cap = yahoo_ads_display.models.campaign_service_frequency_cap.CampaignServiceFrequencyCap(
                                frequency_level = 'CAMPAIGN',
                                frequency_time_unit = 'DAY',
                                impression = 56, ),
                            labels = [
                                yahoo_ads_display.models.campaign_service_label.CampaignServiceLabel(
                                    color = '0',
                                    description = '0',
                                    label_id = 56,
                                    label_name = '0', )
                                ],
                            serving_status = 'SERVING',
                            start_date = '0',
                            type = 'STANDARD',
                            user_status = 'ACTIVE',
                            viewable_frequency_cap = yahoo_ads_display.models.campaign_service_viewable_frequency_cap.CampaignServiceViewableFrequencyCap(
                                v_imps = 56, ), ),
                        errors = [
                            yahoo_ads_display.models.error.Error(
                                code = '0',
                                message = '0',
                                details = [
                                    yahoo_ads_display.models.error_detail.ErrorDetail(
                                        request_key = '0',
                                        request_value = '0', )
                                    ], )
                            ],
                        operation_succeeded = True, )
                    ]
            )
        else :
            return CampaignServiceReturnValue(
        )

    def testCampaignServiceReturnValue(self):
        """Test CampaignServiceReturnValue"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Yahoo!広告 ディスプレイ広告 API リファレンス / Yahoo! Ads Display Ads API Reference

    <div lang=\"ja\">Yahoo!広告 ディスプレイ広告 APIのWebサービスについて説明します。<br> 「Try it out」のご利用には、事前にアプリケーションの登録が必要です。また、アプリケーションのリダイレクトURIの1つに<br> https://yahoojp-marketing.github.io/ads-display-api-documents/oauth2-redirect.htmlを登録してください。 </div> <div lang=\"en\">Display Ads API Web Services supported in Yahoo! Ads API.<br> When you use \"Try it out\", you need to register your application in advance.<br> As one of redirect URI for application, you need to set \"https://yahoojp-marketing.github.io/ads-display-api-documents/oauth2-redirect.html\". </div>   # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from yahoo_ads_display.configuration import Configuration


class DictionaryServiceCategoryChild(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'code': 'str',
        'full_name': 'str',
        'name': 'str',
        'reach_desktop': 'int',
        'reach_smartphone': 'int',
        'reach_tablet': 'int'
    }

    attribute_map = {
        'code': 'code',
        'full_name': 'fullName',
        'name': 'name',
        'reach_desktop': 'reachDesktop',
        'reach_smartphone': 'reachSmartphone',
        'reach_tablet': 'reachTablet'
    }

    def __init__(self, code=None, full_name=None, name=None, reach_desktop=None, reach_smartphone=None, reach_tablet=None, local_vars_configuration=None):  # noqa: E501
        """DictionaryServiceCategoryChild - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._code = None
        self._full_name = None
        self._name = None
        self._reach_desktop = None
        self._reach_smartphone = None
        self._reach_tablet = None
        self.discriminator = None

        self.code = code
        self.full_name = full_name
        self.name = name
        self.reach_desktop = reach_desktop
        self.reach_smartphone = reach_smartphone
        self.reach_tablet = reach_tablet

    @property
    def code(self):
        """Gets the code of this DictionaryServiceCategoryChild.  # noqa: E501

        <div lang=\"ja\">カテゴリコードです。</div> <div lang=\"en\">Category code.</div>   # noqa: E501

        :return: The code of this DictionaryServiceCategoryChild.  # noqa: E501
        :rtype: str
        """
        return self._code

    @code.setter
    def code(self, code):
        """Sets the code of this DictionaryServiceCategoryChild.

        <div lang=\"ja\">カテゴリコードです。</div> <div lang=\"en\">Category code.</div>   # noqa: E501

        :param code: The code of this DictionaryServiceCategoryChild.  # noqa: E501
        :type: str
        """

        self._code = code

    @property
    def full_name(self):
        """Gets the full_name of this DictionaryServiceCategoryChild.  # noqa: E501

        <div lang=\"ja\">カテゴリ名称です。（カテゴリ名称、サブカテゴリ名称を含めた正式名称です。）</div> <div lang=\"en\">Category name in high level.</div>   # noqa: E501

        :return: The full_name of this DictionaryServiceCategoryChild.  # noqa: E501
        :rtype: str
        """
        return self._full_name

    @full_name.setter
    def full_name(self, full_name):
        """Sets the full_name of this DictionaryServiceCategoryChild.

        <div lang=\"ja\">カテゴリ名称です。（カテゴリ名称、サブカテゴリ名称を含めた正式名称です。）</div> <div lang=\"en\">Category name in high level.</div>   # noqa: E501

        :param full_name: The full_name of this DictionaryServiceCategoryChild.  # noqa: E501
        :type: str
        """

        self._full_name = full_name

    @property
    def name(self):
        """Gets the name of this DictionaryServiceCategoryChild.  # noqa: E501

        <div lang=\"ja\">サブカテゴリ名称です。</div> <div lang=\"en\">Category name.</div>   # noqa: E501

        :return: The name of this DictionaryServiceCategoryChild.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this DictionaryServiceCategoryChild.

        <div lang=\"ja\">サブカテゴリ名称です。</div> <div lang=\"en\">Category name.</div>   # noqa: E501

        :param name: The name of this DictionaryServiceCategoryChild.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def reach_desktop(self):
        """Gets the reach_desktop of this DictionaryServiceCategoryChild.  # noqa: E501

        <div lang=\"ja\">PCのリーチ実績数です。</div> <div lang=\"en\">Reach record number of PC</div>   # noqa: E501

        :return: The reach_desktop of this DictionaryServiceCategoryChild.  # noqa: E501
        :rtype: int
        """
        return self._reach_desktop

    @reach_desktop.setter
    def reach_desktop(self, reach_desktop):
        """Sets the reach_desktop of this DictionaryServiceCategoryChild.

        <div lang=\"ja\">PCのリーチ実績数です。</div> <div lang=\"en\">Reach record number of PC</div>   # noqa: E501

        :param reach_desktop: The reach_desktop of this DictionaryServiceCategoryChild.  # noqa: E501
        :type: int
        """

        self._reach_desktop = reach_desktop

    @property
    def reach_smartphone(self):
        """Gets the reach_smartphone of this DictionaryServiceCategoryChild.  # noqa: E501

        <div lang=\"ja\">スマホのリーチ実績数です。</div> <div lang=\"en\">Reach record number of smartphone</div>   # noqa: E501

        :return: The reach_smartphone of this DictionaryServiceCategoryChild.  # noqa: E501
        :rtype: int
        """
        return self._reach_smartphone

    @reach_smartphone.setter
    def reach_smartphone(self, reach_smartphone):
        """Sets the reach_smartphone of this DictionaryServiceCategoryChild.

        <div lang=\"ja\">スマホのリーチ実績数です。</div> <div lang=\"en\">Reach record number of smartphone</div>   # noqa: E501

        :param reach_smartphone: The reach_smartphone of this DictionaryServiceCategoryChild.  # noqa: E501
        :type: int
        """

        self._reach_smartphone = reach_smartphone

    @property
    def reach_tablet(self):
        """Gets the reach_tablet of this DictionaryServiceCategoryChild.  # noqa: E501

        <div lang=\"ja\">タブレットのリーチ実績数です。</div> <div lang=\"en\">Reach record number of tablet</div>   # noqa: E501

        :return: The reach_tablet of this DictionaryServiceCategoryChild.  # noqa: E501
        :rtype: int
        """
        return self._reach_tablet

    @reach_tablet.setter
    def reach_tablet(self, reach_tablet):
        """Sets the reach_tablet of this DictionaryServiceCategoryChild.

        <div lang=\"ja\">タブレットのリーチ実績数です。</div> <div lang=\"en\">Reach record number of tablet</div>   # noqa: E501

        :param reach_tablet: The reach_tablet of this DictionaryServiceCategoryChild.  # noqa: E501
        :type: int
        """

        self._reach_tablet = reach_tablet

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DictionaryServiceCategoryChild):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, DictionaryServiceCategoryChild):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Yahoo!広告 ディスプレイ広告 API リファレンス / Yahoo! Ads Display Ads API Reference

    <div lang=\"ja\">Yahoo!広告 ディスプレイ広告 APIのWebサービスについて説明します。<br> 「Try it out」のご利用には、事前にアプリケーションの登録が必要です。また、アプリケーションのリダイレクトURIの1つに<br> https://yahoojp-marketing.github.io/ads-display-api-documents/oauth2-redirect.htmlを登録してください。 </div> <div lang=\"en\">Display Ads API Web Services supported in Yahoo! Ads API.<br> When you use \"Try it out\", you need to register your application in advance.<br> As one of redirect URI for application, you need to set \"https://yahoojp-marketing.github.io/ads-display-api-documents/oauth2-redirect.html\". </div>   # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from yahoo_ads_display.configuration import Configuration


class AdGroupAdServiceMobileAd(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'description': 'str',
        'description2': 'str',
        'display_url': 'str',
        'headline': 'str',
        'mobile_carriers': 'list[AdGroupAdServiceCarrierName]',
        'url': 'str'
    }

    attribute_map = {
        'description': 'description',
        'description2': 'description2',
        'display_url': 'displayUrl',
        'headline': 'headline',
        'mobile_carriers': 'mobileCarriers',
        'url': 'url'
    }

    def __init__(self, description=None, description2=None, display_url=None, headline=None, mobile_carriers=None, url=None, local_vars_configuration=None):  # noqa: E501
        """AdGroupAdServiceMobileAd - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._description = None
        self._description2 = None
        self._display_url = None
        self._headline = None
        self._mobile_carriers = None
        self._url = None
        self.discriminator = None

        self.description = description
        self.description2 = description2
        self.display_url = display_url
        self.headline = headline
        self.mobile_carriers = mobile_carriers
        self.url = url

    @property
    def description(self):
        """Gets the description of this AdGroupAdServiceMobileAd.  # noqa: E501

        <div lang=\"ja\"> 説明文（1行目）です。<br> このフィールドは、ADD時は必須となり、SET時は省略可能となります。 </div> <div lang=\"en\"> Description text (line 1).<br> This field is required in ADD operation, and will be optional in SET operation. </div>   # noqa: E501

        :return: The description of this AdGroupAdServiceMobileAd.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this AdGroupAdServiceMobileAd.

        <div lang=\"ja\"> 説明文（1行目）です。<br> このフィールドは、ADD時は必須となり、SET時は省略可能となります。 </div> <div lang=\"en\"> Description text (line 1).<br> This field is required in ADD operation, and will be optional in SET operation. </div>   # noqa: E501

        :param description: The description of this AdGroupAdServiceMobileAd.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def description2(self):
        """Gets the description2 of this AdGroupAdServiceMobileAd.  # noqa: E501

        <div lang=\"ja\"> 説明文（2行目）です。<br> ADDおよびSET時、このフィールドは省略可能となります。 </div> <div lang=\"en\"> Description text (line 2).<br> This field is optional in ADD and SET operation. </div>   # noqa: E501

        :return: The description2 of this AdGroupAdServiceMobileAd.  # noqa: E501
        :rtype: str
        """
        return self._description2

    @description2.setter
    def description2(self, description2):
        """Sets the description2 of this AdGroupAdServiceMobileAd.

        <div lang=\"ja\"> 説明文（2行目）です。<br> ADDおよびSET時、このフィールドは省略可能となります。 </div> <div lang=\"en\"> Description text (line 2).<br> This field is optional in ADD and SET operation. </div>   # noqa: E501

        :param description2: The description2 of this AdGroupAdServiceMobileAd.  # noqa: E501
        :type: str
        """

        self._description2 = description2

    @property
    def display_url(self):
        """Gets the display_url of this AdGroupAdServiceMobileAd.  # noqa: E501

        <div lang=\"ja\"> 表示URLです。<br> ADDおよびSET時、このフィールドは省略可能となります。<br> ・標準キャンペーンの場合<br> &nbsp;&nbsp;ADDでは入力必須です。SETでの入力は任意です。<br> ・アプリキャンペーンの場合<br> &nbsp;&nbsp;ADD、SETのどちらも指定できません。<br> &nbsp;&nbsp;※アプリキャンペーンで指定したDeviceOsTypeに基づき、以下のいずれかのURLが自動で設定されます。<br> &nbsp;&nbsp;&nbsp;&nbsp;- iOSの場合：itunes.apple.com<br> &nbsp;&nbsp;&nbsp;&nbsp;- Androidの場合：play.google.com<br> </div> <div lang=\"en\"> Display URL.<br> This field is optional in ADD and SET operation.<br> - Standard campaign:<br> &nbsp;&nbsp;Required for ADD, optional for SET.<br> - Mobile app campaign:<br> &nbsp;&nbsp;Not allowed for ADD and SET.<br> &nbsp;&nbsp;*Based on DeviceOsType specified on Mobile app campaign, any of the following URLs will be automatically set.<br> &nbsp;&nbsp;&nbsp;&nbsp;- For iOS : itunes.apple.com<br> &nbsp;&nbsp;&nbsp;&nbsp;- For Android : play.google.com<br> </div>   # noqa: E501

        :return: The display_url of this AdGroupAdServiceMobileAd.  # noqa: E501
        :rtype: str
        """
        return self._display_url

    @display_url.setter
    def display_url(self, display_url):
        """Sets the display_url of this AdGroupAdServiceMobileAd.

        <div lang=\"ja\"> 表示URLです。<br> ADDおよびSET時、このフィールドは省略可能となります。<br> ・標準キャンペーンの場合<br> &nbsp;&nbsp;ADDでは入力必須です。SETでの入力は任意です。<br> ・アプリキャンペーンの場合<br> &nbsp;&nbsp;ADD、SETのどちらも指定できません。<br> &nbsp;&nbsp;※アプリキャンペーンで指定したDeviceOsTypeに基づき、以下のいずれかのURLが自動で設定されます。<br> &nbsp;&nbsp;&nbsp;&nbsp;- iOSの場合：itunes.apple.com<br> &nbsp;&nbsp;&nbsp;&nbsp;- Androidの場合：play.google.com<br> </div> <div lang=\"en\"> Display URL.<br> This field is optional in ADD and SET operation.<br> - Standard campaign:<br> &nbsp;&nbsp;Required for ADD, optional for SET.<br> - Mobile app campaign:<br> &nbsp;&nbsp;Not allowed for ADD and SET.<br> &nbsp;&nbsp;*Based on DeviceOsType specified on Mobile app campaign, any of the following URLs will be automatically set.<br> &nbsp;&nbsp;&nbsp;&nbsp;- For iOS : itunes.apple.com<br> &nbsp;&nbsp;&nbsp;&nbsp;- For Android : play.google.com<br> </div>   # noqa: E501

        :param display_url: The display_url of this AdGroupAdServiceMobileAd.  # noqa: E501
        :type: str
        """

        self._display_url = display_url

    @property
    def headline(self):
        """Gets the headline of this AdGroupAdServiceMobileAd.  # noqa: E501

        <div lang=\"ja\"> タイトルです。<br> このフィールドは、ADD時は必須となり、SET時は省略可能となります。 </div> <div lang=\"en\"> Title.<br> This field is required in ADD operation, and will be optional in SET operation. </div>   # noqa: E501

        :return: The headline of this AdGroupAdServiceMobileAd.  # noqa: E501
        :rtype: str
        """
        return self._headline

    @headline.setter
    def headline(self, headline):
        """Sets the headline of this AdGroupAdServiceMobileAd.

        <div lang=\"ja\"> タイトルです。<br> このフィールドは、ADD時は必須となり、SET時は省略可能となります。 </div> <div lang=\"en\"> Title.<br> This field is required in ADD operation, and will be optional in SET operation. </div>   # noqa: E501

        :param headline: The headline of this AdGroupAdServiceMobileAd.  # noqa: E501
        :type: str
        """

        self._headline = headline

    @property
    def mobile_carriers(self):
        """Gets the mobile_carriers of this AdGroupAdServiceMobileAd.  # noqa: E501


        :return: The mobile_carriers of this AdGroupAdServiceMobileAd.  # noqa: E501
        :rtype: list[AdGroupAdServiceCarrierName]
        """
        return self._mobile_carriers

    @mobile_carriers.setter
    def mobile_carriers(self, mobile_carriers):
        """Sets the mobile_carriers of this AdGroupAdServiceMobileAd.


        :param mobile_carriers: The mobile_carriers of this AdGroupAdServiceMobileAd.  # noqa: E501
        :type: list[AdGroupAdServiceCarrierName]
        """

        self._mobile_carriers = mobile_carriers

    @property
    def url(self):
        """Gets the url of this AdGroupAdServiceMobileAd.  # noqa: E501

        <div lang=\"ja\"> リンク先URLです。<br> このフィールドは、ADD時は必須となり、SET時は省略可能となります。 </div> <div lang=\"en\"> Destination URL.<br> This field is required in ADD operation, and will be optional in SET operation. </div>   # noqa: E501

        :return: The url of this AdGroupAdServiceMobileAd.  # noqa: E501
        :rtype: str
        """
        return self._url

    @url.setter
    def url(self, url):
        """Sets the url of this AdGroupAdServiceMobileAd.

        <div lang=\"ja\"> リンク先URLです。<br> このフィールドは、ADD時は必須となり、SET時は省略可能となります。 </div> <div lang=\"en\"> Destination URL.<br> This field is required in ADD operation, and will be optional in SET operation. </div>   # noqa: E501

        :param url: The url of this AdGroupAdServiceMobileAd.  # noqa: E501
        :type: str
        """

        self._url = url

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AdGroupAdServiceMobileAd):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AdGroupAdServiceMobileAd):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Yahoo!広告 ディスプレイ広告 API リファレンス / Yahoo! Ads Display Ads API Reference

    <div lang=\"ja\">Yahoo!広告 ディスプレイ広告 APIのWebサービスについて説明します。<br> 「Try it out」のご利用には、事前にアプリケーションの登録が必要です。また、アプリケーションのリダイレクトURIの1つに<br> https://yahoojp-marketing.github.io/ads-display-api-documents/oauth2-redirect.htmlを登録してください。 </div> <div lang=\"en\">Display Ads API Web Services supported in Yahoo! Ads API.<br> When you use \"Try it out\", you need to register your application in advance.<br> As one of redirect URI for application, you need to set \"https://yahoojp-marketing.github.io/ads-display-api-documents/oauth2-redirect.html\". </div>   # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import yahoo_ads_display
from yahoo_ads_display.models.stats_service_target import StatsServiceTarget  # noqa: E501
from yahoo_ads_display.rest import ApiException

class TestStatsServiceTarget(unittest.TestCase):
    """StatsServiceTarget unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test StatsServiceTarget
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = yahoo_ads_display.models.stats_service_target.StatsServiceTarget()  # noqa: E501
        if include_optional :
            return StatsServiceTarget(
                ad_schedule_target = yahoo_ads_display.models.stats_service_ad_schedule_target.StatsServiceAdScheduleTarget(
                    day_of_week = 'MONDAY',
                    end_hour = 56,
                    start_hour = 56, ),
                age_target = yahoo_ads_display.models.stats_service_age_target.StatsServiceAgeTarget(
                    age = 'GT_RANGE13_14',
                    estimate_flg = 'PAUSED', ),
                app_target = yahoo_ads_display.models.stats_service_app_target.StatsServiceAppTarget(
                    device_app_type = 'APP', ),
                audience_category_target = yahoo_ads_display.models.stats_service_audience_category_target.StatsServiceAudienceCategoryTarget(
                    audience_category_type = '0',
                    category_name_en = '0',
                    category_name_ja = '0', ),
                carrier_target = yahoo_ads_display.models.stats_service_carrier_target.StatsServiceCarrierTarget(
                    carrier_type = 'DOCOMO', ),
                device_target = yahoo_ads_display.models.stats_service_device_target.StatsServiceDeviceTarget(
                    device_type = 'DESKTOP', ),
                gender_target = yahoo_ads_display.models.stats_service_gender_target.StatsServiceGenderTarget(
                    estimate_flg = 'PAUSED',
                    gender = 'ST_MALE', ),
                geo_target = yahoo_ads_display.models.stats_service_geo_target.StatsServiceGeoTarget(
                    geo_name_en = '0',
                    geo_name_ja = '0', ),
                interest_category_target = yahoo_ads_display.models.stats_service_interest_category_target.StatsServiceInterestCategoryTarget(
                    category_full_name_en = '0',
                    category_full_name_ja = '0', ),
                os_target = yahoo_ads_display.models.stats_service_os_target.StatsServiceOsTarget(
                    device_os_type = 'IOS', ),
                os_version_target = yahoo_ads_display.models.stats_service_os_version_target.StatsServiceOsVersionTarget(
                    os_version = '0', ),
                placement_target = yahoo_ads_display.models.stats_service_placement_target.StatsServicePlacementTarget(
                    placement_url_list_name = '0',
                    placement_url_list_type = 'WHITE_LIST', ),
                search_target = yahoo_ads_display.models.stats_service_search_target.StatsServiceSearchTarget(
                    search_keyword_list_name = '0', ),
                site_category_target = yahoo_ads_display.models.stats_service_site_category_target.StatsServiceSiteCategoryTarget(
                    category_full_name_en = '0',
                    category_full_name_ja = '0', ),
                site_retargeting_target = yahoo_ads_display.models.stats_service_site_retargeting_target.StatsServiceSiteRetargetingTarget(
                    target_list_deliver_type = 'INCLUDE',
                    target_list_name = '0', ),
                target_id = '0',
                target_setting = 'NONE',
                target_type = 'AD_SCHEDULE_TARGET'
            )
        else :
            return StatsServiceTarget(
        )

    def testStatsServiceTarget(self):
        """Test StatsServiceTarget"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Yahoo!広告 ディスプレイ広告 API リファレンス / Yahoo! Ads Display Ads API Reference

    <div lang=\"ja\">Yahoo!広告 ディスプレイ広告 APIのWebサービスについて説明します。<br> 「Try it out」のご利用には、事前にアプリケーションの登録が必要です。また、アプリケーションのリダイレクトURIの1つに<br> https://yahoojp-marketing.github.io/ads-display-api-documents/oauth2-redirect.htmlを登録してください。 </div> <div lang=\"en\">Display Ads API Web Services supported in Yahoo! Ads API.<br> When you use \"Try it out\", you need to register your application in advance.<br> As one of redirect URI for application, you need to set \"https://yahoojp-marketing.github.io/ads-display-api-documents/oauth2-redirect.html\". </div>   # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from yahoo_ads_display.configuration import Configuration


class SearchKeywordIdeaServiceSelector(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'keyword_frequency': 'SearchKeywordIdeaServiceKeywordFrequency',
        'keyword_ids': 'list[int]',
        'keyword_recency': 'SearchKeywordIdeaServiceKeywordRecency',
        'keywords': 'list[str]',
        'match_type': 'SearchKeywordIdeaServiceMatchType',
        'number_results': 'int',
        'sort_field': 'SearchKeywordIdeaServiceSortField',
        'sort_type': 'SearchKeywordIdeaServiceSortType',
        'start_index': 'int'
    }

    attribute_map = {
        'keyword_frequency': 'keywordFrequency',
        'keyword_ids': 'keywordIds',
        'keyword_recency': 'keywordRecency',
        'keywords': 'keywords',
        'match_type': 'matchType',
        'number_results': 'numberResults',
        'sort_field': 'sortField',
        'sort_type': 'sortType',
        'start_index': 'startIndex'
    }

    def __init__(self, keyword_frequency=None, keyword_ids=None, keyword_recency=None, keywords=None, match_type=None, number_results=1000, sort_field=None, sort_type=None, start_index=1, local_vars_configuration=None):  # noqa: E501
        """SearchKeywordIdeaServiceSelector - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._keyword_frequency = None
        self._keyword_ids = None
        self._keyword_recency = None
        self._keywords = None
        self._match_type = None
        self._number_results = None
        self._sort_field = None
        self._sort_type = None
        self._start_index = None
        self.discriminator = None

        self.keyword_frequency = keyword_frequency
        self.keyword_ids = keyword_ids
        self.keyword_recency = keyword_recency
        self.keywords = keywords
        self.match_type = match_type
        self.number_results = number_results
        self.sort_field = sort_field
        self.sort_type = sort_type
        self.start_index = start_index

    @property
    def keyword_frequency(self):
        """Gets the keyword_frequency of this SearchKeywordIdeaServiceSelector.  # noqa: E501


        :return: The keyword_frequency of this SearchKeywordIdeaServiceSelector.  # noqa: E501
        :rtype: SearchKeywordIdeaServiceKeywordFrequency
        """
        return self._keyword_frequency

    @keyword_frequency.setter
    def keyword_frequency(self, keyword_frequency):
        """Sets the keyword_frequency of this SearchKeywordIdeaServiceSelector.


        :param keyword_frequency: The keyword_frequency of this SearchKeywordIdeaServiceSelector.  # noqa: E501
        :type: SearchKeywordIdeaServiceKeywordFrequency
        """

        self._keyword_frequency = keyword_frequency

    @property
    def keyword_ids(self):
        """Gets the keyword_ids of this SearchKeywordIdeaServiceSelector.  # noqa: E501

        <div lang=\"ja\"> 検索条件：キーワードID<br> ※キーワード検索用<br> ※キーワード、キーワードIDの同時指定はできません。 </div> <div lang=\"en\">Search condition : Keyword ID.<br> *Keyword for searching.<br> *Can not specify Keyword and Keyword ID at the same time. </div>   # noqa: E501

        :return: The keyword_ids of this SearchKeywordIdeaServiceSelector.  # noqa: E501
        :rtype: list[int]
        """
        return self._keyword_ids

    @keyword_ids.setter
    def keyword_ids(self, keyword_ids):
        """Sets the keyword_ids of this SearchKeywordIdeaServiceSelector.

        <div lang=\"ja\"> 検索条件：キーワードID<br> ※キーワード検索用<br> ※キーワード、キーワードIDの同時指定はできません。 </div> <div lang=\"en\">Search condition : Keyword ID.<br> *Keyword for searching.<br> *Can not specify Keyword and Keyword ID at the same time. </div>   # noqa: E501

        :param keyword_ids: The keyword_ids of this SearchKeywordIdeaServiceSelector.  # noqa: E501
        :type: list[int]
        """

        self._keyword_ids = keyword_ids

    @property
    def keyword_recency(self):
        """Gets the keyword_recency of this SearchKeywordIdeaServiceSelector.  # noqa: E501


        :return: The keyword_recency of this SearchKeywordIdeaServiceSelector.  # noqa: E501
        :rtype: SearchKeywordIdeaServiceKeywordRecency
        """
        return self._keyword_recency

    @keyword_recency.setter
    def keyword_recency(self, keyword_recency):
        """Sets the keyword_recency of this SearchKeywordIdeaServiceSelector.


        :param keyword_recency: The keyword_recency of this SearchKeywordIdeaServiceSelector.  # noqa: E501
        :type: SearchKeywordIdeaServiceKeywordRecency
        """

        self._keyword_recency = keyword_recency

    @property
    def keywords(self):
        """Gets the keywords of this SearchKeywordIdeaServiceSelector.  # noqa: E501

        <div lang=\"ja\"> 検索条件：キーワード<br> ※キーワード提案用<br> ※キーワード、キーワードIDの同時指定はできません。 </div> <div lang=\"en\"> Search condition : Keyword.<br> *Keyword for suggesting.<br> *Can not specify Keyword and Keyword ID at the same time. </div>   # noqa: E501

        :return: The keywords of this SearchKeywordIdeaServiceSelector.  # noqa: E501
        :rtype: list[str]
        """
        return self._keywords

    @keywords.setter
    def keywords(self, keywords):
        """Sets the keywords of this SearchKeywordIdeaServiceSelector.

        <div lang=\"ja\"> 検索条件：キーワード<br> ※キーワード提案用<br> ※キーワード、キーワードIDの同時指定はできません。 </div> <div lang=\"en\"> Search condition : Keyword.<br> *Keyword for suggesting.<br> *Can not specify Keyword and Keyword ID at the same time. </div>   # noqa: E501

        :param keywords: The keywords of this SearchKeywordIdeaServiceSelector.  # noqa: E501
        :type: list[str]
        """

        self._keywords = keywords

    @property
    def match_type(self):
        """Gets the match_type of this SearchKeywordIdeaServiceSelector.  # noqa: E501


        :return: The match_type of this SearchKeywordIdeaServiceSelector.  # noqa: E501
        :rtype: SearchKeywordIdeaServiceMatchType
        """
        return self._match_type

    @match_type.setter
    def match_type(self, match_type):
        """Sets the match_type of this SearchKeywordIdeaServiceSelector.


        :param match_type: The match_type of this SearchKeywordIdeaServiceSelector.  # noqa: E501
        :type: SearchKeywordIdeaServiceMatchType
        """

        self._match_type = match_type

    @property
    def number_results(self):
        """Gets the number_results of this SearchKeywordIdeaServiceSelector.  # noqa: E501

        <div lang=\"ja\">ページの最大件数です。このフィールドは、1以上を指定する必要があります。</div> <div lang=\"en\">Maximum number of results to return in this page. This field must be greater than or equal to 1. Also see Entity Limits per operation.</div>   # noqa: E501

        :return: The number_results of this SearchKeywordIdeaServiceSelector.  # noqa: E501
        :rtype: int
        """
        return self._number_results

    @number_results.setter
    def number_results(self, number_results):
        """Sets the number_results of this SearchKeywordIdeaServiceSelector.

        <div lang=\"ja\">ページの最大件数です。このフィールドは、1以上を指定する必要があります。</div> <div lang=\"en\">Maximum number of results to return in this page. This field must be greater than or equal to 1. Also see Entity Limits per operation.</div>   # noqa: E501

        :param number_results: The number_results of this SearchKeywordIdeaServiceSelector.  # noqa: E501
        :type: int
        """
        if (self.local_vars_configuration.client_side_validation and
                number_results is not None and number_results > 1000):  # noqa: E501
            raise ValueError("Invalid value for `number_results`, must be a value less than or equal to `1000`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                number_results is not None and number_results < 1):  # noqa: E501
            raise ValueError("Invalid value for `number_results`, must be a value greater than or equal to `1`")  # noqa: E501

        self._number_results = number_results

    @property
    def sort_field(self):
        """Gets the sort_field of this SearchKeywordIdeaServiceSelector.  # noqa: E501


        :return: The sort_field of this SearchKeywordIdeaServiceSelector.  # noqa: E501
        :rtype: SearchKeywordIdeaServiceSortField
        """
        return self._sort_field

    @sort_field.setter
    def sort_field(self, sort_field):
        """Sets the sort_field of this SearchKeywordIdeaServiceSelector.


        :param sort_field: The sort_field of this SearchKeywordIdeaServiceSelector.  # noqa: E501
        :type: SearchKeywordIdeaServiceSortField
        """

        self._sort_field = sort_field

    @property
    def sort_type(self):
        """Gets the sort_type of this SearchKeywordIdeaServiceSelector.  # noqa: E501


        :return: The sort_type of this SearchKeywordIdeaServiceSelector.  # noqa: E501
        :rtype: SearchKeywordIdeaServiceSortType
        """
        return self._sort_type

    @sort_type.setter
    def sort_type(self, sort_type):
        """Sets the sort_type of this SearchKeywordIdeaServiceSelector.


        :param sort_type: The sort_type of this SearchKeywordIdeaServiceSelector.  # noqa: E501
        :type: SearchKeywordIdeaServiceSortType
        """

        self._sort_type = sort_type

    @property
    def start_index(self):
        """Gets the start_index of this SearchKeywordIdeaServiceSelector.  # noqa: E501

        <div lang=\"ja\">ページの先頭のインデックスです。このフィールドは、1以上を指定する必要があります。</div> <div lang=\"en\">Index of the first result to return in this page. This field must be greater than or equal to 1.</div>   # noqa: E501

        :return: The start_index of this SearchKeywordIdeaServiceSelector.  # noqa: E501
        :rtype: int
        """
        return self._start_index

    @start_index.setter
    def start_index(self, start_index):
        """Sets the start_index of this SearchKeywordIdeaServiceSelector.

        <div lang=\"ja\">ページの先頭のインデックスです。このフィールドは、1以上を指定する必要があります。</div> <div lang=\"en\">Index of the first result to return in this page. This field must be greater than or equal to 1.</div>   # noqa: E501

        :param start_index: The start_index of this SearchKeywordIdeaServiceSelector.  # noqa: E501
        :type: int
        """
        if (self.local_vars_configuration.client_side_validation and
                start_index is not None and start_index < 1):  # noqa: E501
            raise ValueError("Invalid value for `start_index`, must be a value greater than or equal to `1`")  # noqa: E501

        self._start_index = start_index

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SearchKeywordIdeaServiceSelector):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, SearchKeywordIdeaServiceSelector):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Yahoo!広告 ディスプレイ広告 API リファレンス / Yahoo! Ads Display Ads API Reference

    <div lang=\"ja\">Yahoo!広告 ディスプレイ広告 APIのWebサービスについて説明します。<br> 「Try it out」のご利用には、事前にアプリケーションの登録が必要です。また、アプリケーションのリダイレクトURIの1つに<br> https://yahoojp-marketing.github.io/ads-display-api-documents/oauth2-redirect.htmlを登録してください。 </div> <div lang=\"en\">Display Ads API Web Services supported in Yahoo! Ads API.<br> When you use \"Try it out\", you need to register your application in advance.<br> As one of redirect URI for application, you need to set \"https://yahoojp-marketing.github.io/ads-display-api-documents/oauth2-redirect.html\". </div>   # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import yahoo_ads_display
from yahoo_ads_display.models.report_definition_service_get_response import ReportDefinitionServiceGetResponse  # noqa: E501
from yahoo_ads_display.rest import ApiException

class TestReportDefinitionServiceGetResponse(unittest.TestCase):
    """ReportDefinitionServiceGetResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test ReportDefinitionServiceGetResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = yahoo_ads_display.models.report_definition_service_get_response.ReportDefinitionServiceGetResponse()  # noqa: E501
        if include_optional :
            return ReportDefinitionServiceGetResponse(
                errors = [
                    yahoo_ads_display.models.error.Error(
                        code = '0',
                        message = '0',
                        details = [
                            yahoo_ads_display.models.error_detail.ErrorDetail(
                                request_key = '0',
                                request_value = '0', )
                            ], )
                    ],
                rid = '0',
                rval = yahoo_ads_display.models.report_definition_service_page.ReportDefinitionServicePage(
                    total_num_entries = 56,
                    values = [
                        yahoo_ads_display.models.report_definition_service_value.ReportDefinitionServiceValue(
                            errors = [
                                yahoo_ads_display.models.error.Error(
                                    code = '0',
                                    message = '0',
                                    details = [
                                        yahoo_ads_display.models.error_detail.ErrorDetail(
                                            request_key = '0',
                                            request_value = '0', )
                                        ], )
                                ],
                            operation_succeeded = True,
                            report_definition = yahoo_ads_display.models.report_definition.ReportDefinition(
                                account_id = 56,
                                complete_time = '0',
                                date_range = yahoo_ads_display.models.report_definition_service_date_range.ReportDefinitionServiceDateRange(
                                    end_date = '0',
                                    start_date = '0', ),
                                date_range_type = 'CUSTOM_DATE',
                                download_encode = 'UTF-8',
                                download_format = 'CSV',
                                fields = [
                                    '0'
                                    ],
                                filters = [
                                    yahoo_ads_display.models.report_definition_service_filter.ReportDefinitionServiceFilter(
                                        field = '0',
                                        filter_operator = 'EQUALS', )
                                    ],
                                frequency_range = 'DAILY',
                                job_status = 'ACCEPTED',
                                lang = 'JA',
                                report_job_error_detail = '0',
                                report_job_id = 56,
                                report_name = '0',
                                request_time = '0',
                                sort_fields = [
                                    yahoo_ads_display.models.report_definition_service_report_sort_field.ReportDefinitionServiceReportSortField(
                                        field = '0',
                                        report_sort_type = 'ASC', )
                                    ],
                                zip = 'ON', ), )
                        ], )
            )
        else :
            return ReportDefinitionServiceGetResponse(
        )

    def testReportDefinitionServiceGetResponse(self):
        """Test ReportDefinitionServiceGetResponse"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Yahoo!広告 ディスプレイ広告 API リファレンス / Yahoo! Ads Display Ads API Reference

    <div lang=\"ja\">Yahoo!広告 ディスプレイ広告 APIのWebサービスについて説明します。<br> 「Try it out」のご利用には、事前にアプリケーションの登録が必要です。また、アプリケーションのリダイレクトURIの1つに<br> https://yahoojp-marketing.github.io/ads-display-api-documents/oauth2-redirect.htmlを登録してください。 </div> <div lang=\"en\">Display Ads API Web Services supported in Yahoo! Ads API.<br> When you use \"Try it out\", you need to register your application in advance.<br> As one of redirect URI for application, you need to set \"https://yahoojp-marketing.github.io/ads-display-api-documents/oauth2-redirect.html\". </div>   # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import yahoo_ads_display
from yahoo_ads_display.models.conversion_tracker_service_mutate_response import ConversionTrackerServiceMutateResponse  # noqa: E501
from yahoo_ads_display.rest import ApiException

class TestConversionTrackerServiceMutateResponse(unittest.TestCase):
    """ConversionTrackerServiceMutateResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test ConversionTrackerServiceMutateResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = yahoo_ads_display.models.conversion_tracker_service_mutate_response.ConversionTrackerServiceMutateResponse()  # noqa: E501
        if include_optional :
            return ConversionTrackerServiceMutateResponse(
                errors = [
                    yahoo_ads_display.models.error.Error(
                        code = '0',
                        message = '0',
                        details = [
                            yahoo_ads_display.models.error_detail.ErrorDetail(
                                request_key = '0',
                                request_value = '0', )
                            ], )
                    ],
                rid = '0',
                rval = yahoo_ads_display.models.conversion_tracker_service_return_value.ConversionTrackerServiceReturnValue(
                    values = [
                        yahoo_ads_display.models.conversion_tracker_service_value.ConversionTrackerServiceValue(
                            conversion_tracker = yahoo_ads_display.models.conversion_tracker.ConversionTracker(
                                account_id = 56,
                                all_conversion_value = '0',
                                all_conversions = 56,
                                app_conversion = yahoo_ads_display.models.conversion_tracker_service_app_conversion.ConversionTrackerServiceAppConversion(
                                    app_conversion_platform = 'ITUNES',
                                    app_conversion_type = 'FIRST_OPEN',
                                    app_id = '0', ),
                                category = 'NONE',
                                conversion_tracker_id = 56,
                                conversion_tracker_name = '0',
                                conversion_tracker_type = 'WEB_CONVERSION',
                                conversion_value = '0',
                                conversion_value_via_ad_click = '0',
                                conversions = 56,
                                conversions_via_ad_click = 56,
                                counting_type = 'ONE_PER_CLICK',
                                cross_device_conversions = 56,
                                exclude_from_bidding = 'FALSE',
                                measurement_period = 56,
                                measurement_period_view = 56,
                                most_recent_conversion_date = '0',
                                status = 'ENABLED',
                                user_revenue_value = 56,
                                web_conversion = yahoo_ads_display.models.conversion_tracker_service_web_conversion.ConversionTrackerServiceWebConversion(
                                    snippet = [
                                        yahoo_ads_display.models.conversion_tracker_service_web_conversion_snippet.ConversionTrackerServiceWebConversionSnippet(
                                            tag = '0',
                                            web_conversion_snippet_type = 'IMG', )
                                        ], ), ),
                            errors = [
                                yahoo_ads_display.models.error.Error(
                                    code = '0',
                                    message = '0',
                                    details = [
                                        yahoo_ads_display.models.error_detail.ErrorDetail(
                                            request_key = '0',
                                            request_value = '0', )
                                        ], )
                                ],
                            operation_succeeded = True,
                            stats_period_custom_date = yahoo_ads_display.models.conversion_tracker_service_stats_period_custom_date.ConversionTrackerServiceStatsPeriodCustomDate(
                                stats_end_date = '0',
                                stats_start_date = '0', ), )
                        ], )
            )
        else :
            return ConversionTrackerServiceMutateResponse(
        )

    def testConversionTrackerServiceMutateResponse(self):
        """Test ConversionTrackerServiceMutateResponse"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Yahoo!広告 ディスプレイ広告 API リファレンス / Yahoo! Ads Display Ads API Reference

    <div lang=\"ja\">Yahoo!広告 ディスプレイ広告 APIのWebサービスについて説明します。<br> 「Try it out」のご利用には、事前にアプリケーションの登録が必要です。また、アプリケーションのリダイレクトURIの1つに<br> https://yahoojp-marketing.github.io/ads-display-api-documents/oauth2-redirect.htmlを登録してください。 </div> <div lang=\"en\">Display Ads API Web Services supported in Yahoo! Ads API.<br> When you use \"Try it out\", you need to register your application in advance.<br> As one of redirect URI for application, you need to set \"https://yahoojp-marketing.github.io/ads-display-api-documents/oauth2-redirect.html\". </div>   # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import yahoo_ads_display
from yahoo_ads_display.models.retargeting_list_service_value import RetargetingListServiceValue  # noqa: E501
from yahoo_ads_display.rest import ApiException

class TestRetargetingListServiceValue(unittest.TestCase):
    """RetargetingListServiceValue unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test RetargetingListServiceValue
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = yahoo_ads_display.models.retargeting_list_service_value.RetargetingListServiceValue()  # noqa: E501
        if include_optional :
            return RetargetingListServiceValue(
                errors = [
                    yahoo_ads_display.models.error.Error(
                        code = '0',
                        message = '0',
                        details = [
                            yahoo_ads_display.models.error_detail.ErrorDetail(
                                request_key = '0',
                                request_value = '0', )
                            ], )
                    ],
                operation_succeeded = True,
                retargeting_list = yahoo_ads_display.models.retargeting_list.RetargetingList(
                    account_id = 56,
                    delivery_status = 'ACTIVE',
                    description = '0',
                    reach = 56,
                    target_list = yahoo_ads_display.models.retargeting_list_service_target_list.RetargetingListServiceTargetList(
                        combination_target_list = yahoo_ads_display.models.retargeting_list_service_combination_target_list.RetargetingListServiceCombinationTargetList(
                            combinations = [
                                yahoo_ads_display.models.retargeting_list_service_combination.RetargetingListServiceCombination(
                                    logical_operator = 'OR',
                                    target_lists = [
                                        yahoo_ads_display.models.retargeting_list_service_target_list_data.RetargetingListServiceTargetListData(
                                            target_list_id = 56,
                                            target_list_name = '0', )
                                        ], )
                                ], ),
                        custom_audience_target_list = yahoo_ads_display.models.retargeting_list_service_custom_audience_target_list.RetargetingListServiceCustomAudienceTargetList(
                            custom_audience_id = '0',
                            reach_period = 56, ),
                        rule_target_list = yahoo_ads_display.models.retargeting_list_service_rule_target_list.RetargetingListServiceRuleTargetList(
                            is_open = 'TRUE',
                            is_preset = 'TRUE',
                            reach_period = 56,
                            retargeting_tag_id = '0',
                            rules = [
                                yahoo_ads_display.models.retargeting_list_service_rule.RetargetingListServiceRule(
                                    rule_conditions = [
                                        yahoo_ads_display.models.retargeting_list_service_rule_condition.RetargetingListServiceRuleCondition(
                                            compare_operator = 'EQUAL',
                                            rule_type = 'URL',
                                            value = '0', )
                                        ], )
                                ], ),
                        similarity_target_list = yahoo_ads_display.models.retargeting_list_service_similarity_target_list.RetargetingListServiceSimilarityTargetList(
                            target_list_id = 56,
                            target_list_size = 'RATE_1',
                            target_list_size_reaches = [
                                yahoo_ads_display.models.retargeting_list_service_target_list_size_reaches.RetargetingListServiceTargetListSizeReaches(
                                    reach = 56, )
                                ], ),
                        target_list_type = 'DEFAULT_LIST', ),
                    target_list_id = 56,
                    target_list_name = '0', )
            )
        else :
            return RetargetingListServiceValue(
        )

    def testRetargetingListServiceValue(self):
        """Test RetargetingListServiceValue"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Yahoo!広告 ディスプレイ広告 API リファレンス / Yahoo! Ads Display Ads API Reference

    <div lang=\"ja\">Yahoo!広告 ディスプレイ広告 APIのWebサービスについて説明します。<br> 「Try it out」のご利用には、事前にアプリケーションの登録が必要です。また、アプリケーションのリダイレクトURIの1つに<br> https://yahoojp-marketing.github.io/ads-display-api-documents/oauth2-redirect.htmlを登録してください。 </div> <div lang=\"en\">Display Ads API Web Services supported in Yahoo! Ads API.<br> When you use \"Try it out\", you need to register your application in advance.<br> As one of redirect URI for application, you need to set \"https://yahoojp-marketing.github.io/ads-display-api-documents/oauth2-redirect.html\". </div>   # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import yahoo_ads_display
from yahoo_ads_display.models.media_service_get_response import MediaServiceGetResponse  # noqa: E501
from yahoo_ads_display.rest import ApiException

class TestMediaServiceGetResponse(unittest.TestCase):
    """MediaServiceGetResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test MediaServiceGetResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = yahoo_ads_display.models.media_service_get_response.MediaServiceGetResponse()  # noqa: E501
        if include_optional :
            return MediaServiceGetResponse(
                errors = [
                    yahoo_ads_display.models.error.Error(
                        code = '0',
                        message = '0',
                        details = [
                            yahoo_ads_display.models.error_detail.ErrorDetail(
                                request_key = '0',
                                request_value = '0', )
                            ], )
                    ],
                rid = '0',
                rval = yahoo_ads_display.models.media_service_page.MediaServicePage(
                    total_num_entries = 56,
                    values = [
                        yahoo_ads_display.models.media_service_value.MediaServiceValue(
                            errors = [
                                yahoo_ads_display.models.error.Error(
                                    code = '0',
                                    message = '0',
                                    details = [
                                        yahoo_ads_display.models.error_detail.ErrorDetail(
                                            request_key = '0',
                                            request_value = '0', )
                                        ], )
                                ],
                            operation_succeeded = True,
                            media_record = yahoo_ads_display.models.media_service_record.MediaServiceRecord(
                                account_id = 56,
                                approval_status = 'APPROVED',
                                campaign_banner_flg = 'FALSE',
                                creation_time = '0',
                                disapproval_reason_codes = [
                                    '0'
                                    ],
                                logo_flg = 'FALSE',
                                image_media = yahoo_ads_display.models.media_service_image_media.MediaServiceImageMedia(
                                    media_type = 'IMAGE',
                                    aspect_ratio = '0',
                                    data = 'YQ==',
                                    file_size = 56,
                                    height = 56,
                                    media_ad_format = '0',
                                    media_file_type = 'JPEG',
                                    width = 56, ),
                                media_id = 56,
                                media_name = '0',
                                media_title = '0',
                                thumbnail_flg = 'FALSE',
                                user_status = 'ACTIVE', ), )
                        ], )
            )
        else :
            return MediaServiceGetResponse(
        )

    def testMediaServiceGetResponse(self):
        """Test MediaServiceGetResponse"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()
